#!/bin/bash
# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of buildpackage
#
# buildpackage is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This is the update bootstrap

# ------------------------------------------------------------------------------
# This function verifies if the package MD5 is correct
verify_md5(){
    printf "[SEED2-update] Checking MD5... "
    if [[ ${MD5_CHECK} == $(md5sum "${SEED_MEC_HOME}/update/tmp/${FILE}" | \
                            awk '{print $1}') ]]; then
        printf "OK!\n"
    else
        printf "ERROR: This package is currupted.\n"
        rm -rf ${FILE} &> /dev/null
        exit 1
    fi
}

# ------------------------------------------------------------------------------
# Re-create the inep and proxy's MD5
restore_inep_proxy_md5sum(){
    for FILE in inep proxy; do
        md5sum "${SEED_MEC_HOME}/SEED2/client/conf/${FILE}" |cut -d' ' -f1 > \
               "${SEED_MEC_HOME}/${UPDATE_DIR}/.md5sum/client/conf/${FILE}"

        # The backup md5 is the same
        cp -a "${SEED_MEC_HOME}/${UPDATE_DIR}/.md5sum/client/conf/${FILE}" \
               "${SEED_MEC_HOME}/${UPDATE_DIR}/.md5sum/.backup/client/conf/"
    done
}

# ------------------------------------------------------------------------------
# Re-create the inep and proxy files' backup and copy the MD5 files
restore_inep_proxy_backup(){
    for FILE in inep proxy; do
        # The backup itself
        cp -a "${SEED_MEC_HOME}/SEED2/client/conf/${FILE}" \
              "${SEED_MEC_HOME}/${UPDATE_DIR}/.backup/client/conf/"
    done
}

# ------------------------------------------------------------------------------
# These variables will be replaced while generating the package
FILE=
MD5_CHECK=
BOOTSTRAP_LINES=

if test -n "${HOME}"; then
    SEED_MEC_HOME=${HOME}
else
    SEED_MEC_HOME=/opt/seed_mec
fi
UPDATE_DIR="update/tmp/SEED2-run"

# ------------------------------------------------------------------------------
# Create auxiliar directories
mkdir -p "${SEED_MEC_HOME}/update/tmp"
mkdir -p "${SEED_MEC_HOME}/update/old"

# Extract the tar package
tail -n +${BOOTSTRAP_LINES} "$0" > "${SEED_MEC_HOME}/update/tmp/${FILE}"
verify_md5
cd "${SEED_MEC_HOME}/update/tmp"
tar xzf "${FILE}" &> /dev/null
cd - &> /dev/null

# ------------------------------------------------------------------------------
# Make sure the directories exist in the update tree to backup the inep and
# proxy files, along with their counterparts (backup and MD5)
mkdir -p "${SEED_MEC_HOME}/update/tmp/SEED2-run/client/conf"
mkdir -p "${SEED_MEC_HOME}/update/tmp/SEED2-run/.md5sum/client/conf"
mkdir -p "${SEED_MEC_HOME}/update/tmp/SEED2-run/.backup/client/conf"
mkdir -p "${SEED_MEC_HOME}/update/tmp/SEED2-run/.md5sum/.backup/client/conf"

# Check if the inep and proxy files exist
ERROR=0
INEP_PROXY="${SEED_MEC_HOME}/SEED2/client/conf/inep
            ${SEED_MEC_HOME}/SEED2/client/conf/proxy"
for FILE in ${INEP_PROXY}; do
    test -f "${FILE}" || ERROR=1
done

# Copy the inep and proxy files. Also, copy their backups and MD5 counterparts,
# if they exist. Otherwise, create them
if test "${ERROR}" -eq 0; then

    # Copy inep and proxy to the new tree
    cp -a "${SEED_MEC_HOME}/SEED2/client/conf/"{inep,proxy} \
          "${SEED_MEC_HOME}/update/tmp/SEED2-run/client/conf/"

    # Copy or create the md5 files from inep and proxy
    (test -d "${SEED_MEC_HOME}/SEED2/.md5sum" &&
        cp -a "${SEED_MEC_HOME}/SEED2/.md5sum/client/conf/"{inep,proxy} \
              "${SEED_MEC_HOME}/update/tmp/SEED2-run/.md5sum/client/conf/" &&
        cp -a "${SEED_MEC_HOME}/SEED2/.md5sum/.backup/client/conf/"{inep,proxy} \
              "${SEED_MEC_HOME}/update/tmp/SEED2-run/.md5sum/.backup/client/conf/") ||
    restore_inep_proxy_md5sum

    # Copy or create the backup files from inep and proxy
    (test -d "${SEED_MEC_HOME}/SEED2/.backup" &&
        cp -a "${SEED_MEC_HOME}/SEED2/.backup/client/conf/"{inep,proxy} \
              "${SEED_MEC_HOME}/update/tmp/SEED2-run/.backup/client/conf/") ||
    restore_inep_proxy_backup

fi

# ------------------------------------------------------------------------------
# TODO: do some security backup???
#cp -ra "${SEED_MEC_HOME}/SEED2/" "${SEED_MEC_HOME}/old/"

# If something interrupts the script here, the tree will not be entirely
# correct, so a file is created to mark that something happened. During the next
# next execution the package will try to recover itself
##### CRITICAL #####
touch "${SEED_MEC_HOME}/SEED2/updating"

# md5sum and backup folders
rm -rf "${SEED_MEC_HOME}/SEED2/.md5sum" \
       "${SEED_MEC_HOME}/SEED2/.backup" &> /dev/null
mv -f "${SEED_MEC_HOME}/update/tmp/SEED2-run/"{.md5*,.back*}* \
      "${SEED_MEC_HOME}/SEED2/"

# Copy the files themself
rm -rf "${SEED_MEC_HOME}/SEED2/"{*.sh,bin,lib,net,client,extra,network-scripts,scripts} &> /dev/null
mv -f "${SEED_MEC_HOME}/update/tmp/SEED2-run/"* \
      "${SEED_MEC_HOME}/SEED2/"

rm -f "${SEED_MEC_HOME}/SEED2/updating" &> /dev/null
### END CRITICAL ###

# ------------------------------------------------------------------------------
# Remove auxiliar directories
rm -rf "${SEED_MEC_HOME}/update" &> /dev/null

#Fix the le-autoupgrade on LE 5
if test -f /etc/le_version && \
    dpkg --compare-versions $(cat /etc/le_version ) gt 4; then
    sudo rm -f '/etc/apt/sources.list.d/quantal-repos.list'
fi

# Call the agent
"${SEED_MEC_HOME}/SEED2/update.sh"

exit 0
