#!/bin/bash
# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of buildpackage
#
# buildpackage is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script downloads and compiles the wget binary. Exit status:
#
# 0 - Success
# 1 - Error while trying to download wget
# 2 - Error while trying to unpack wget package
# 3 - Error while trying to configure wget
# 4 - Error while trying to compile wget

# ------------------------------------------------------------------------------
PREFIX="$(dirname $0)"

# Check if wget is already compiled
if test -x wget-*/src/wget; then
    printf "Wget already compiled. %b" \
        "Remove its folder if you want to recompile it.\n"
    exit 0
fi

printf "====================\n$0 v0.1\n\n"
printf "**** Make sure that you are connected to the internet!!!\n"
printf "====================\n\n"

# Remove old builds
rm -Rf wget-*

# Download the latest wget package
wget http://gnu.c3sl.ufpr.br/ftp/wget/wget-1.13.4.tar.gz -O wget.tar.gz || \
  (printf "ERROR (1): Failed to download the latest wget version. %b" \
          "Aborting...\n" && exit 1)

# Unpack
tar xvzf wget.tar.gz &> /dev/null || \
  (printf "ERROR (2): Failed to unpack wget. Aborting...\n" && exit 2)

# Configure and compile
cd wget-*
CFLAGS=-m32 ./configure --without-ssl --disable-opie --disable-digest \
            --disable-ntlm --disable-debug --disable-nls --disable-largefile \
            --disable-ipv6 --disable-rpath --disable-iri || \
  (printf "ERROR (3): Failed to configure wget. Aborting...\n" && exit 3)

make LDFLAGS=-static ||
  (printf "ERROR (4): Failed to compile wget. Aborting...\n" && exit 4)

cd - &> /dev/null

printf "\nAll done.\n\n"
exit 0
