#!/bin/bash
# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of buildpackage
#
# buildpackage is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script creates MD5 files and the necessary backup from the agent files to
# allow the agent to check its files' integrity. Exit status:
#
# 0 - Success
# 1 - Error while trying to load conf file
# 2 - Error while trying to change to the agent's directory

# ------------------------------------------------------------------------------
PREFIX="$(dirname $0)"

# Get the configuration
if ! source "${PREFIX}/buildpackage.conf" 2> /dev/null; then
    printf "ERROR (1): Failed to load buildpackage.conf.\n"
    exit 1
fi

# Customizable variables. Please refer to buildpackage.conf to change these
# values
: ${AGENTDIR:="agent-files"}
: ${AGENTPACKAGEDIR:="SEED2-run"}

BASEDIR="${AGENTDIR}/${AGENTPACKAGEDIR}"
MD5DIR=".md5sum"
BACKUPDIR=".backup"

# The list of files to backup. client/conf/{inep,proxy} will be added in the
# creation process
BACKUPLIST="agent.conf extra-tincuca.sh inventory.sh load-config.sh
network-usage.sh update.sh integrity-checker.sh bin/collect-parser bin/wget
client/run.sh client/common.sh client/bin/client client/conf/version"

printf "====================\n$0 v0.1\n\nNOTE: Make sure this is the last %b" \
       "thing you do before publishing the package.\n====================\n\n"

# ------------------------------------------------------------------------------
if ! cd "${BASEDIR}"; then
    printf "ERROR (2): Something went wrong: can't access the agent files. %b" \
           "Aborting...\n"
    exit 2
fi

rm -Rf "${MD5DIR}" 2> /dev/null
mkdir -p "${MD5DIR}"

printf "Starting backup files creation... "
mkdir -p "${BACKUPDIR}/client/"{conf,bin}
mkdir -p "${BACKUPDIR}/bin"
for FILE in ${BACKUPLIST}; do
    cp -a "${FILE}" "${BACKUPDIR}/${FILE}"
done
printf "done.\n"

printf "Calculating md5... "
for FOLDER in $(find . -type d); do
    mkdir -p "${MD5DIR}/${FOLDER}"
done

for FILE in $(find . -type f); do
    md5sum "${FILE}" |cut -d' ' -f1 > "${MD5DIR}/${FILE}"
done
printf "done.\n"

printf "\nAll done.\n"
exit 0
