#!/bin/bash
# run.sh

# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of client
#
# client is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

dirname=$(dirname $0)
basename=$(basename ${dirname})
bindir=${dirname}/bin
log=${dirname}/run.log

# Redirects all error output to log file
exec 2>> ${log}

# Timestamp
date +"%F %T" >> ${log}

# Get common functions
source ${dirname}/common.sh

url="--url=http://200.17.202.187/tomcat/axis/Seed2.jws"
inep=$(cat ${dirname}/conf/inep 2> /dev/null)
if test ! -f "${dirname}/conf/inep" -o -z "${inep}"; then
    printf "WARNING: inep file not found or empty.\n" >> ${log}
fi

getProxyConf
# Add a prefix to each non empty proxy information
test -n "${phost}" && phost="--phost=${phost}"
test -n "${pport}" && pport="--pport=${pport}"
test -n "${puid}" && puid="--puid=${puid}"
test -n "${ppasswd}" && ppasswd="--ppasswd=${ppasswd}"
proxy="${phost} ${pport} ${puid} ${ppasswd}"

inep="--inep=${inep}"

interface=""
if test $(/sbin/route | grep default | wc -l) -gt 1; then
    getNetworkInterface
    interface="--nic=${interface}"
fi

# Execution
if test $# -ne 1; then
    echo "ERROR: run.sh call: wrong number of parameters ($#)." >> ${log}
    exit 101
elif [[ $1 == "--inventory" || $1 == "--net-usage" ]]; then
    ${bindir}/client $1 ${url} ${inep} ${proxy} ${interface} >> ${log}
elif [[ $1 == "--update" ]]; then
    retstr=$(${bindir}/client $1 ${url} ${proxy} ${interface})
    retval=$?
    if test ${retval} -eq 4; then
        echo "$retstr" | tee -a ${log}
    fi
    exit $retval
else
    echo "ERROR: run.sh call: wrong parameter (\"$1\")." >> ${log}
    exit 102
fi
