#!/usr/bin/env python
# -*- coding: utf-8 -*-

from tcp import TCPServer
from misc import Log, readConf

class RemoteLogServer(TCPServer):
    def __init__(self, host="localhost"):

        self.__conf = readConf()
        self.__log = Log(self.__conf["log"])
        self.__port = int(self.__conf["remoteport"])

        TCPServer.__init__(self, "", self.__port)

        self.__quit = False

    def quit(self):
        self.__quit = True

    def log(self, msg):
        self.__log.log(msg)

    def init(self):
        while not self.__quit:
            connection, address = self.accept()
            while True:
                data = connection.recv(1024).strip()
                if data:
                    for line in data.split("\n"):
                        self.log(data)
                else:
                    break
            connection.close()

if __name__ == "__main__":
    import sys
    rls = RemoteLogServer()
    try:
        rls.init()
    except KeyboardInterrupt:
        rls.quit()
        sys.exit(1)
    sys.exit(0)
