#!/bin/bash

# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of collect-agent
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script will install/update tincuca-server on Metasys Servers
# of the RUCA project

LOGDIR=${HOME}/SEED2/log
LOGFILE=${LOGDIR}/tincucaclient-install.log
MYVERSION=/etc/tincuca-client/version
LASTVERSIONURL=http://colombard.c3sl.ufpr.br/update/tincuca-client-version
PACKAGEURL=http://colombard.c3sl.ufpr.br/update/tincuca-client.rpm
PACKPATH=/tmp/tincuca-client-new.rpm
RUNASROOT=${HOME}/SEED2/extra/runasroot.sh
TESTINEPSFILE=${HOME}/SEED2/extra/testineps.txt
PROINFOINEPFILE=/opt/seed_mec/SEED2/client/conf/inep

mkdir -p ${LOGDIR}

printLog () {
    date +"%F %T - $1"
}

# Print all the output to the logfile
exec 1>> ${LOGFILE} 2>&1

# Check if I am a Metasys Server
if ! grep -q "Metasys School Server" /etc/issue ; then
    printLog "This is not a Metasys School Server. Aborting."
    exit 0
fi

# Check if I am a test server
INEP=$(mysql -u root -D -s -N MetasysMonit -e "select INEP from INEP")
if test $? -ne 0 || test -z "$INEP"; then
    # MetasysMonitor not configured, trying to get INEP from PROINFODATA
    if test -f ${PROINFOINEPFILE}; then
        INEP=$(cat $PROINFOINEPFILE)
    fi
fi
if test -z "${INEP}" || ! grep -q "${INEP}" ${TESTINEPSFILE} ; then
    printLog "This is not a test server. Aborting."
    exit 0
fi

# Make seed_mec a sudoer
SUDOERS=/etc/sudoers
$RUNASROOT "chmod 644 ${SUDOERS}"
if ! grep -q seed_mec ${SUDOERS} ; then
    $RUNASROOT "echo -e \"seed_mec\tALL=(ALL) NOPASSWD: ALL\" >> ${SUDOERS}"
fi
$RUNASROOT "chmod 440 ${SUDOERS}"

if test -f ${MYVERSION} ; then

    # Get last version
    LASTVERSION=$(mktemp)
    if ! wget -q ${LASTVERSIONURL} -O ${LASTVERSION} ; then
        printLog "Error while getting the last version!"
        exit 1
    fi

    # Compare versions
    if [[ "$(cat ${LASTVERSION})" == "$(cat ${MYVERSION})" ]]; then
        printLog "Already up-to-date."
        rm -f ${LASTVERSION}
        exit 0
    fi
else
    # tincuca-client isn't installed yet. Try to get its dependences
    DEPLISTURL=http://colombard.c3sl.ufpr.br/update/tincuca-deps/install_order
    DEPLIST=$(mktemp)
    if ! wget -q ${DEPLISTURL} -O ${DEPLIST} ; then
        printLog "Error while getting the depencies list"
        exit 2
    fi
    for package in $(cat ${DEPLIST}); do
        printLog "Getting ${package}..."
        DEPPACK=$(mktemp)
        if ! wget -q -O ${DEPPACK} \
             http://colombard.c3sl.ufpr.br/update/tincuca-deps/${package}
        then
            printLog "Error while getting ${package}!"
            exit 3
        fi
        sudo rpm -i --force ${DEPPACK}
        rm -f ${DEPPACK}
    done
fi

printLog "Installing the lastest version of tincuca-client..."
rm -f ${LASTVERSION}

# Try to download the newest package
rm -f ${PACKPATH}
if ! wget -q ${PACKAGEURL} -O ${PACKPATH}; then
    printLog "Error while getting the newest package!"
    exit 4
fi

# Remove old versions
sudo rpm -e tincuca-client || true

# Install new version
sudo rpm -i --force --nodeps ${PACKPATH}

# Restart tinc if it's already running
if $(pgrep -fx "${TINCMD}( -D|)" &>/dev/null); then
    sudo tincd -n vpn -k
fi

# Open tinc connection
sudo /usr/local/bin/tincuca-client.sh

exit 0
