#!/bin/bash
# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of collect-agent
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script loads the configuration file and all of its valid variables. Exit
# status:
#
# 0 - Success
# 1 - Error

# ------------------------------------------------------------------------------
# Function: message
# Treat output error stream.
# Parameters:
# $1: error ID
# $2: output Stream (default stderr)
function message()
{
  stream="/proc/self/fd/1"

  test -n "$2" && stream="$2"

  case $1 in
    1)
      date +"%F %T - ERROR: Config file not found." > ${stream}
      ;;
    *)
      date +"%F %T - ERROR: Unknown event." > ${stream}
      ;;
  esac

  return $1
}

# ------------------------------------------------------------------------------
declare SCRIPTPATH="$0" DEFAULTCONFIG="agent.conf"

if test $# -gt 1 -a -f "$1"; then
  conf=$(readlink -f $1)
elif test -f "${PREFIX}/${DEFAULTCONFIG}"; then
  conf="${PREFIX}/${DEFAULTCONFIG}"
else
  message 1 /proc/self/fd/2; exit 1
fi

# Read config file and declare only valid variables
while read var; do
  test -n "$(echo $var | egrep -i "^[a-z_]+=")" && eval "declare ${var}"
done < ${conf}

# Create "tmp", "data" and "log" directories
mkdir -p ${TMPDIR} ${DATADIR} ${LOGDIR}
