#!/bin/bash
# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of collect-agent
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script rotates the collect log file if it has expired. Exit status:
#
# 0 - Success
# 1 - Error while rolling log file

# ------------------------------------------------------------------------------
# Function: rotateLogFile
# If the log file is out-of-date (set by $2), execute savelog(1) to rotate it.
# Parameters:
# $1: log file name
# $2: time in days to expire
# $3: save $3 versions of the log file
function rotateLogFile()
{
    find "${LOGDIR}" -type f -name "$1" -atime +$2 -exec savelog -c $3 {} \; ||
    return 1

    return 0
}

# ------------------------------------------------------------------------------
export PREFIX="$(dirname $(readlink -f $0))"
source ${PREFIX}/load-config.sh || exit 1

exec >> ${LOGFILE} 2>&1

date +"%F %T - Start of rotate log execution."

# Rotate the log file if it has already expired
if ! rotateLogFile '*.log' ${DAYSTOEXPIRELOG} 12; then
    date +"%F %T - Error while rolling log file."
    exit 1
fi

date +"%F %T - Rotate log terminated successfully."
exit 0
