#!/bin/bash
# Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of collect-agent
#
# collect-agent is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# This script updates the agent if there's a new version available. Exit status:
#
# 0 - Success
# 1 - Error while loading configuration
# 2 - Error to edit crontab
# 3 - Error while trying to update the agent

# ------------------------------------------------------------------------------
# Function: checkUpdate
# Verify and download the new version of the agent.
function checkUpdate()
{
    updateLink="$(${CLIENT} --update)"
    returnValue=$?

    if test ${returnValue} -eq 4; then
        test -f "${TMPDIR}/SEED2-update.run" || rm -f ${TMPDIR}/SEED2-update.run

        tryWget ${updateLink} \
                -O ${TMPDIR}/SEED2-update.run || return 1

        cd ${TMPDIR}

        # If $FIST_EXECUTION is set, do not run the update. Otherwise, run the
        # update and return 1 in case of error
        test "${FIRST_EXECUTION}" || bash ${TMPDIR}/SEED2-update.run || return 1

        rm -f ${TMPDIR}/SEED2-update.run

        # Return 0 if this is the first execution of the agent
        test "${FIRST_EXECUTION}" && return 0
    fi

    return ${returnValue}
}

# ------------------------------------------------------------------------------
# Function: schedule
# Check scheduling in the user's crontab and write the new schedule in case
# there wasn't one or if it was different.
function schedule()
{
    if test -f "${CLIENTCONFDIR}/inep"; then
        MIN=$(( 10#$(sed "s/[^0-9]//g" ${CLIENTCONFDIR}/inep) % 60 ))
    else
        MIN=$(( $RANDOM % 60 ))
    fi

    userCron="$(printf\
        "${MIN} ${SCHEDULE}\n${NETSCHEDULE}\n@reboot ${PREFIX}/update.sh\n")"

    if test "$(crontab -l)" != "${userCron}"; then
        printf "${userCron}\n\n" | crontab - || return 1
    fi

    return 0
}

# ------------------------------------------------------------------------------
export PREFIX="$(dirname $(readlink -f $0))"
source ${PREFIX}/load-config.sh || exit 1
source ${PREFIX}/client/common.sh

exec >> ${LOGFILE} 2>&1

date +"%F %T - Start of update process execution."

# Edit crontab if it isn't correct
if ! schedule; then
    date +"%F %T - Error to edit crontab."
    exit 2
fi

# If this is the agent's first execution, save the version and force the update
# process to happen by setting the version to "0.0.0"
if test "${FIRST_EXECUTION}"; then
    REALVERSION=$(cat "${VERSIONFILE}")
    echo "0.0.0" > "${VERSIONFILE}"
fi

checkUpdate
updateStatus=$?

# Restore the real version of the agent, if this is its first execution
test "${FIRST_EXECUTION}" && echo "${REALVERSION}" > "${VERSIONFILE}"

test ${updateStatus} -eq 4 && exit 0
if test ${updateStatus} -ne 0; then
    date +"%F %T - Error while trying to update the agent."
    exit 3
fi

date +"%F %T - Update process terminated successfully."
exit 0
