-- dimension city
CREATE TABLE dim_city (
    id          SERIAL PRIMARY KEY,
    name        CHARACTER VARYING(100) NOT NULL,
    state       CHARACTER VARYING(2) NOT NULL,
    region      CHARACTER VARYING(12) NOT NULL,
    CHECK (name <> ''),
    CHECK (state <> ''),
    CHECK (region <> '')
);

-- dimension school
CREATE TABLE dim_school (
    id          SERIAL PRIMARY KEY,
    cit_id      INTEGER NOT NULL REFERENCES dim_city,
    inep        CHARACTER VARYING(12) NOT NULL,
    name        CHARACTER VARYING(150) NOT NULL,
    address     CHARACTER VARYING(100),
    cep         CHARACTER VARYING(10),
    CHECK (inep <> ''),
    CHECK (name <> '')
);

-- dimension date
CREATE TABLE dim_date (
    id          DATE PRIMARY KEY,
    day         SMALLINT NOT NULL,
    month       SMALLINT NOT NULL,
    year        SMALLINT NOT NULL,
    CHECK (TO_DATE(year || '-' || month || '-' || day, 'YYYY-MM-DD') = id)
);

-- dimension inventory
CREATE TABLE dim_inventory (
    id          SERIAL PRIMARY KEY,
    sch_id      INTEGER NOT NULL REFERENCES dim_school,
    macaddr     MACADDR NOT NULL,
    load_date   DATE NOT NULL DEFAULT CURRENT_DATE REFERENCES dim_date,
    project     project_enum DEFAULT 'proinfo' NOT NULL,

    -- inventory info
    disk1_model TEXT NOT NULL,
    disk1_size  INTEGER NOT NULL,
    disk1_used  INTEGER NOT NULL,
    disk2_model TEXT,
    disk2_size  INTEGER,
    disk2_used  INTEGER,

    memory      INTEGER NOT NULL,
    processor   TEXT NOT NULL,
    os_type     TEXT NOT NULL,
    os_distro   TEXT NOT NULL,
    os_kernel   TEXT NOT NULL,

    is_first    BIT NOT NULL DEFAULT '0',
    is_current  BIT NOT NULL DEFAULT '1',

    CHECK (macaddr <> '00:00:00:00:00:00')
);
