CREATE OR REPLACE FUNCTION load_aggr_availability() returns void as $$
DECLARE
    date_it date;
    start_ts TIMESTAMP;
    total_rows INTEGER;
    cur_rows INTEGER;
BEGIN

    -- getting initial timestamp
    start_ts = CLOCK_TIMESTAMP();
    total_rows := 0;

    -- remove the index - later we create it again
    DROP INDEX IF EXISTS aggr_availability_base_date_idx;

    -- remove old data
    TRUNCATE TABLE aggr_availability;

    -- iterate over past months
    FOR i IN 0..5 LOOP
        date_it := CURRENT_DATE - (i *  interval '1 month');

        INSERT INTO aggr_availability
        SELECT
            date_it,
            f.macaddr,
            f.project,
            s.inep,
            s.name,
            c.name,
            c.state,
            c.region,
            CASE WHEN date_it - max_dat_id <= 10 THEN 1 ELSE 0 END as is_green,
            CASE WHEN date_it - max_dat_id > 10 AND date_it - max_dat_id <= 30 THEN 1 ELSE 0 END as is_yellow,
            CASE WHEN date_it - max_dat_id > 30 THEN 1 ELSE 0 END as is_red
        FROM
            (SELECT
                max(dat_id) as max_dat_id,
                f.sch_id,
                f.cit_id,
                f.macaddr,
                f.project
            FROM
                fact_contact f
            WHERE
                dat_id <= date_it
            GROUP BY
                f.cit_id, f.sch_id, f.macaddr, f.project) as f
        INNER JOIN
            dim_school s
        ON
            f.sch_id = s.id
        INNER JOIN
            dim_city c
        ON
            f.cit_id = c.id;

        -- how many rows were inserted?
        GET DIAGNOSTICS cur_rows := ROW_COUNT;
        total_rows := total_rows + cur_rows;

    END LOOP;

    -- creating index to speed-up per-date queries, and it speeds up a lot..
    CREATE INDEX aggr_availability_base_date_idx ON aggr_availability(base_date);

    -- logging
    INSERT INTO control (name, start_time, end_time, total)
        VALUES ('loading aggr_availability', start_ts, CLOCK_TIMESTAMP(), total_rows);
END;
$$ language plpgsql;
