/*
 * seed2_graphs.js
 *
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of portal
 *
 * portal is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/*
 * This file contains all functions used in SEED2 project page:
 * Monitoramento Automatico dos Laboratorios das Escolas Publicas Brasileiras.
 * We used Web Services concepts with AJAX to get information about dynamic
 * contents (i.e. new versions of documentations)
 *
 * @author Rubens Massayuki Suguimoto
 */

/*
 * @brief Parse AJAX HTTP SOAP response.
 *
 * @param HttpRequest    XML HTTP Request object with SOAP response.
 * @return   empty string
 *
 * @author Rubens Massayuki Suguimoto
 * @author Renan Franca de Miranda
 */
function receiveResponse(HttpRequest, url){

    var Status;
    var parent, graph, response, respTmp, parse, areas, href;
    var i;

    if (HttpRequest.readyState == 4)
    {
        try
        {
            Status = HttpRequest.status;
        }
        catch(e)
        {
            document.write(e);
            return "";
        }
        if(Status == 200)
        {
            parent = document.getElementById("seed2_content_center");
            if(parent)
            {
                graph = document.getElementById("seed2_content_center_graph");
                if(graph)
                {
                    parent.removeChild(graph);
                }

                var lists = parent.getElementsByTagName("ul");
                for(var i=lists.length-1; i>=0 ; i--)
                {
                    parent.removeChild(lists[i]);
                }

                response = HttpRequest.responseText;

                /*Fix the HTML of Pentaho*/
                respTmp = response.replace(/\n/g,"");
                respTmp = respTmp.replace(/\t/g,"");
                respTmp = respTmp.replace(/\ \ /g,"");
                respTmp = respTmp.replace(/<br>/g,"");
                respTmp = respTmp.replace(/><\/center>/g,"/><\/center>");

                /*Does the hierarchy of the country in the form of links.*/
                parent.appendChild(makePath(url));

                response = respTmp;
                graph = document.createElement("div");
                graph.setAttribute("id","seed2_content_center_graph");
                graph.innerHTML = response;
                parent.appendChild(graph);

                var param = url.split("?")[1];
                var type = null;
                if(typeof(param) != "undefined")
                {
                    var parans = param.split("&")[0];
                    var type = parans.split("=")[1];
                }

                /*Creates the links in the bar chart*/
                parent = document.getElementById("Bar_chart");
                areas = parent.getElementsByTagName("area");
                for(i=0;i<areas.length;i++)
                {
                    href = areas[i].getAttribute("href");
                    areas[i].removeAttribute("href");
                    areas[i].removeAttribute("title");
                    areas[i].setAttribute("onmouseover", "document.getElementById('Bar_chart').style.cursor='pointer'");
                    areas[i].setAttribute("onmouseout", "document.getElementById('Bar_chart').style.cursor='default'");
                    if(type != "Cidade")
                    {
                        areas[i].setAttribute("onclick", "graf('/tomcat/pentaho/"+href+"')");
                    }
                    else
                    {
                        var graph = graphType();
                        if ((graph == "Audit") && (i%2==0))
                        {
                            href2 = href.replace("auditRelatorio.xaction", "auditRelatorioRoxo.xaction");
                            areas[i].setAttribute("onclick", "window.open('/tomcat/pentaho/"+href2+"')");
                        }
                        else
                            areas[i].setAttribute("onclick", "window.open('/tomcat/pentaho/"+href+"')");
                    }
                }

                /*Remove links from the pie and line charts*/
                parent = document.getElementById("Pie_chart");
                if (parent)
                {
                    areas = parent.getElementsByTagName("area");
                    for(i=0;i<areas.length;i++)
                    {
                        areas[i].removeAttribute("href");
                        areas[i].removeAttribute("title");
                        areas[i].setAttribute("style","cursor:default");
                    }
                }

                parent = document.getElementById("Line_chart");
                areas = parent.getElementsByTagName("area");
                for(i=0;i<areas.length;i++)
                {
                    areas[i].removeAttribute("href");
                    areas[i].removeAttribute("title");
                    areas[i].setAttribute("style", "cursor:default");
                }
            }
        }
    }
}

/*
 * @brief Call the AJAX function to assemble graphics.
 *
 * @param url    URL to be processed by the parser.
 *
 * @author Renan Franca de Miranda
 */
    function graf(url){
        if(url != null)
        {
            ajax("", url, receiveResponse);
        }
        else
        {
            var project = projectName();
            var graph = graphType();
            ajax("", "/tomcat/pentaho/"+project+graph, receiveResponse);
        }
    }

/*
 * @brief Mount the hierarchy in the form of links.
 *
 * @param url    URL to know the hierarchy to be mounted.
 *
 * @author Rubens Massayuki Suguimoto
 */
function makePath(url)
{
    var list = document.createElement("ul");
    list.id="line_list";

    var i;
    var country = document.createElement("li");
    var regions = null;
    var region = null;
    var state = null;
    var city = null

    country.innerHTML = "BRASIL";
    list.appendChild(country);

    var param = url.split("?");
    if (param.length > 1)
    {
        var parans = param[1].split("&");

        var type = parans[0].split("=")[1];

        var graph = graphType();

        var project = projectName();

        switch(type)
        {
            case "Regiao":
                country.onclick = function(){graf();}
                country.className="link";
                regions = document.createElement("li");
                regions.innerHTML="REGIÕES";
                list.appendChild(regions);
                break;

            case "Estado":
                country.onclick = function(){graf();}
                country.className="link";
                regions = document.createElement("li");
                regions.innerHTML="REGIÕES";
                regions.className="link";
                regions.onclick = function(){graf('/tomcat/pentaho/'+project+graph+'?type=Regiao');}
                list.appendChild(regions);

                region = document.createElement("li");
                var region_name = parans[1].split("=")[1];
                region.innerHTML=region_name;
                list.appendChild(region);
                break;

            case "Cidade":
                country.onclick = function(){graf();}
                country.className="link";
                regions = document.createElement("li");
                regions.innerHTML="REGIÕES";
                regions.className="link";
                regions.onclick = function(){graf('/tomcat/pentaho/'+project+graph+'?type=Regiao');}
                list.appendChild(regions);

                region = document.createElement("li");
                var region_name = parans[1].split("=")[1];
                region.innerHTML=region_name;
                region.className="link";
                region.onclick = function(){graf('/tomcat/pentaho/'+project+graph+'?type=Estado&region='+region_name);}
                list.appendChild(region);

                state = document.createElement("li");
                var state_name = parans[2].split("=")[1];
                state.innerHTML=state_name;
                list.appendChild(state);

                break;
            }
    }

    return list;
}

/*
 * @brief Reads the 'proj' variable on the URL and determines which tab should
 * be selected.
 *
 * @author Aryane Ast dos Santos
 */
function selectDefaultTab()
{
    var project = (window.location.hash).substring(1);
    if (project)
        switchTab("menu_"+project);
    else
        switchTab("menu_ProInfo");
}

window.onload=selectDefaultTab;
