/*
 * seed2_graphs_fast_search.js
 *
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of portal
 *
 * portal is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/**
 * This file contains all functions used in SEED2 project page:
 * Monitoramento Automatico dos Laboratorios das Escolas Publicas Brasileiras.
 * We used Web Services concepts with AJAX to get information about dynamic
 * contents (i.e. new versions of documentations)
 *
 * @author Rubens Massayuki Suguimoto
 */

/* Global variable to store Speed Search link */
var speedSearchLink = "/tomcat/pentaho/Seed2Search";
/* Global variable to store report link */
var newLink;

/**
 * @brief Parse AJAX HTTP SOAP response.
 *
 * @param HttpRequest    XML HTTP Request object with SOAP response.
 * @return   empty string
 *
 * @author Rubens Massayuki Suguimoto
 * @author Renan Franca de Miranda
 */
function receiveResponse(HttpRequest,url) {

    var Status;
    var parent, speedSearch, response, respTmp;

    if (HttpRequest.readyState == 4)
    {
        try
        {
            Status = HttpRequest.status;
        }
        catch(e)
        {
            document.write(e);
            return "";
        }
        if (Status == 200)
        {
            parent = document.getElementById("seed2_content_center");
            if (parent)
            {
                response = HttpRequest.responseText;

                /* Fix the HTML of Pentaho */
                respTmp = response.replace(/\n/g,"");
                respTmp = respTmp.replace(/\t/g,"");
                respTmp = respTmp.replace(/\ \ /g,"");
                respTmp = respTmp.replace(/<br>/g,"");
                respTmp = respTmp.replace(/><\/center>/g,"/><\/center>");

                response = respTmp;
                speedSearch = document.createElement("div");
                speedSearch.setAttribute("id","seed2_content_center_search");
                speedSearch.innerHTML = response;
                parent.appendChild(speedSearch);

                updateLink(speedSearchLink);
            }
        }
    }
}

/**
 * @brief Reset Speed Search link
 *
 * @author Renan Franca de Miranda
 */
function reset()
{
    speedSearchLink = "";
    modifyLink("/tomcat/pentaho/Seed2Search");
}

/**
 * @brief Reload the Speed Search page according to the passed parameter
 *
 * @param link Speed Search link
 *
 * @author Renan Franca de Miranda
 */
function modifyLink(link)
{
    var centerParent, centerChild;

    centerParent = document.getElementById("seed2_content_center");
    centerChild = document.getElementById("seed2_content_center_search");
    centerParent.removeChild(centerChild);

    speedSearchLink += link;
    //alert(speedSearchLink);
    ajax("", speedSearchLink, receiveResponse);
}

/**
 * @brief Update Speed Search link while the parameters are being selected
 *
 * @param link Speed Search link
 *
 * @author Renan Franca de Miranda
 */
function updateLink(link)
{
    var projectContent = document.getElementById("span_project_value");
    var typeContent = document.getElementById("span_type_value");
    var objType = document.getElementById("select_type");
    var objRegion = document.getElementById("select_region");
    var objState = document.getElementById("select_state");
    var objCity = document.getElementById("select_city");
    var objSchool = document.getElementById("select_school");
    var objDate = document.getElementById("select_date");
    var trSchool = document.getElementById("tr_school");
    var trDate = document.getElementById("tr_date");
    var objInput = document.getElementById("make");
    var linkPath = link.split("?");
    var type, region, state, city;
    var school, date, project;

    if (linkPath[1])
    {
        linkPath = linkPath[1].replace(/\+/g, " ");
        linkPath = linkPath.split("=");
        if (linkPath[1])
        {
            project = linkPath[1];
            project = project.split("&")[0];
        }
        if (linkPath[2])
        {
            type = linkPath[2];
            type = type.split("&")[0];
        }
        if (linkPath[3])
        {
            region = linkPath[3];
            region = region.split("&")[0];
        }
        if (linkPath[4])
        {
            state = linkPath[4];
            state = state.split("&")[0];
        }
        if (linkPath[5])
        {
            city = linkPath[5];
            city = city.split("&")[0];
        }
        if (linkPath[6])
        {
            school = linkPath[6];
            school = school.split("&")[0];
        }
        if (linkPath[7])
        {
            date = linkPath[7];
        }
    }

    if (project)
    {
        hide(document.getElementById("select_project"));
        objType.disabled = false;
        objRegion.disabled = true;
        objState.disabled = true;
        objCity.disabled = true;
        objSchool.disabled = true;
        objDate.disabled = true;

        switch (project) {
            case "proinfo":
                projectContent.innerHTML = "Máquina PROINFO";
            break;
            case "uca-classmate":
                projectContent.innerHTML = "UCA Classmate";
            break;
            case "uca-server":
                projectContent.innerHTML = "UCA Server";
            break;
            case "projector":
                projectContent.innerHTML = "Projetor PROINFO";
            break;
        }
    }

    if (type)
    {
        hide(document.getElementById("select_type"));
        objRegion.disabled = false;
        objState.disabled = true;
        objCity.disabled = true;
        objSchool.disabled = true;
        objDate.disabled = true;
        objInput.disabled = true;

        switch (type) {
            case "disp":
                typeContent.innerHTML = "Disponibilidade";
            break;
            case "invent":
                typeContent.innerHTML = "Inventário";
            break;
            case "audit":
                typeContent.innerHTML = "Parque computacional instalado";
            break;
            case "audit2":
                typeContent.innerHTML = "Escolas sem o agente instalado";
            break;
            case "alert":
                typeContent.innerHTML = "Alteração de inventário";
            break;
            case "net":
                typeContent.innerHTML = "Uso de rede";
            trSchool.style.display = "table-row";
            trDate.style.display = "table-row";
            break;
        }
    }
    if (region)
    {
        hide(document.getElementById("select_region"));
        document.getElementById("span_region_value").innerHTML = region;
        objState.disabled = false;
        objCity.disabled = true;
        objSchool.disabled = true;
        objDate.disabled = true;
        objInput.disabled = true;
    }
    if (state)
    {
        hide(document.getElementById("select_state"));
        document.getElementById("span_state_value").innerHTML = state;
        objCity.disabled = false;
        objSchool.disabled = true;
        objDate.disabled = true;
        objInput.disabled = true;
    }
    if (city)
    {
        hide(document.getElementById("select_city"));
        document.getElementById("span_city_value").innerHTML = city;
        objSchool.disabled = false;
        objDate.disabled = true;
        if (type == "net")
            objInput.disabled = true;
        else
            objInput.disabled = false;
    }
    if (school)
    {
        hide(document.getElementById("select_school"));
        document.getElementById("span_school_value").innerHTML = school;
        objDate.disabled = false;
        objInput.disabled = true;
    }
    if (date)
    {
        hide(document.getElementById("select_date"));
        document.getElementById("span_date_value").innerHTML = date;
        objInput.disabled = false;
    }
}

/**
 * @brief Hide content
 *
 * @param content HTML content
 *
 * @author Renan Franca de Miranda
 */
function hide(content)
{
    content.style.display = "none";
}

/**
 * @brief Create the appropriate link to generate the specified report
 *
 * @author Renan Franca de Miranda
 */
function makeNewLink()
{
    var type, region, state, city;
    var school, date, project;
    var linkPath = speedSearchLink.split("?");

    if (linkPath[1])
    {
        if (linkPath[1])
        {
            linkPath = linkPath[1].replace(/\+/g, " ");
            linkPath = linkPath.split("=");
            project = linkPath[1];
            project = project.split("&")[0];
        }
        if (linkPath[2])
        {
            type = linkPath[2];
            type = type.split("&")[0];
        }
        if (linkPath[3])
        {
            region = linkPath[3];
            region = region.split("&")[0];
        }
        if (linkPath[4])
        {
            state = linkPath[4];
            state = state.split("&")[0];
        }
        if (linkPath[5])
        {
            city = linkPath[5];
            city = city.split("&")[0];
        }
        if (linkPath[6])
        {
            school = linkPath[6];
            school = school.split("&")[0];
        }
        if (linkPath[7])
        {
            date = linkPath[7];
        }
    }

    speedSearchLink = "/tomcat/pentaho/ViewAction?type=Escola&solution=seed2&path=";

    switch (type) {
        case "disp":
            newLink = speedSearchLink + project + "/disponibilidade&action=dispRelatorio.xaction&REGIAO="
            + region.toUpperCase() + "&ESTADO=" + state + "&CIDADE="
            + city.toUpperCase() + "&output-type=pdf";
            makeGenerateButton();
            window.open(newLink);
        break;

        case "invent":
            newLink = speedSearchLink + project + "/inventario&action=inventRelatorio.xaction&REGIAO="
            + region.toUpperCase() + "&ESTADO=" + state + "&CIDADE="
            + city.toUpperCase() + "&output-type=pdf";
            makeGenerateButton();
            window.open(newLink);
        break;

        case "audit":
            newLink = speedSearchLink + project + "/auditoria&action=auditRelatorio.xaction&REGIAO="
            + region.toUpperCase() + "&ESTADO=" + state + "&CIDADE="
            + city.toUpperCase()+"&output-type=pdf";
            makeGenerateButton();
            window.open(newLink);
        break;

        case "audit2":
            newLink = speedSearchLink + project + "/auditoria&action=auditRelatorioRoxo.xaction&REGIAO="
            + region.toUpperCase() + "&ESTADO=" + state + "&CIDADE="
            + city.toUpperCase() + "&output-type=pdf";
            makeGenerateButton();
            window.open(newLink);
        break;

        case "alert":
            newLink = speedSearchLink + project + "/alertas&action=alertRelatorio.xaction&REGIAO="
            + region.toUpperCase() + "&ESTADO=" + state + "&CIDADE="
            + city.toUpperCase() + "&output-type=pdf";
            makeGenerateButton();
            window.open(newLink);
        break;
        case "net":
            newLink = "/tomcat/pentaho/content/reporting?renderMode=REPORT&solution=seed2&path=network-usage&name=uso_de_rede.prpt&output-target=pageable/pdf&REGIAO="
            + region.toUpperCase() + "&ESTADO=" + state + "&CIDADE="
            + city.toUpperCase() + "&ESCOLA=" + school.toUpperCase()
            + "&DATA=" + date.substring(6,10) + "-" + date.substring(3,5) + "-" + date.substring(0,2) +"&output-type=pdf";
            makeGenerateButton();
            window.open(newLink);
        break;
    }
}

/*
 * @brief Sets the generate report button ("Gerar Relatório") with the link to
 * the pdf report.
 *
 * @author Aryane Ast dos Santos
 */
function makeGenerateButton()
{
    var button = document.getElementById("make");
    button.setAttribute("onclick", "window.open(newLink)");
}
