/*
 * seed2_utils.js
 *
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of portal
 *
 * portal is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/**********************************
 * FUNCTIONS - XML SEARCH
 ************************************/

/**
 * @brief    Identify client web browser and return a value
 *
 * @return   Browser Number
 *               (-1=Not identified,
 *                0=IE,
 *                1=FF2[gecko != 1.9],
 *                2=FF3[gecko1.9])
 * @author   Rubens Suguimoto
 */
function UTILS_IdentifyBrowser()
{
    var BrowserValue;
    var BrowserName=navigator.appName;

    /*Firefox, Mozilla, Opera, etc.*/
    if (BrowserName.match("Netscape"))
    {
        if (
                (/Firefox[\/\s](\d+\.\d+)/.test(navigator.userAgent)) ||
                (/Iceweasel[\/\s](\d+\.\d+)/.test(navigator.userAgent)) ||
                (/Epiphany[\/\s](\d+\.\d+)/.test(navigator.userAgent)) ||
                (/Galeon[\/\s](\d+\.\d+)/.test(navigator.userAgent))
           )
        {
            var geckoVersion;
            var UserAgent = navigator.userAgent.split(" ");
            var i=0;

            while((!UserAgent[i].match("rv:")) && ( i < UserAgent.length))
            {
                i++;
            }

            if(i != UserAgent.length)
            {
                geckoVersion = UserAgent[i].split(":")[1];
                if (geckoVersion.match("1.9"))
                {
                    BrowserValue = 2;
                }
                else
                {
                    BrowserValue = 1;
                }
            }
            else
            {
                alert("User agent without Gecko version.");
            }
        }
        else
        {
            BrowserValue = 1;
        }
    }
    /*Internet Explorer*/
    else if (BrowserName.match("Microsoft Internet Explorer"))
    {
        BrowserValue = 0;
    }
    /*Other*/
    else
    {
        alert("Seu navegador pode não funcionar corretamente nesse site");
        BrowserValue = -1;
    }

    return BrowserValue;
}

/**
 * @brief    Get element content in any browser
 *
 * @param    Node    DOM element
 * @return   Node content string
 * @author   Rubens Suguimoto
 */
function UTILS_GetNodeText(Node)
{
    if (!Node)
        return null;

    /*Internet Explorer*/
    if (Node.text)
    {
        return Node.text;
    }
    /*Mozilla, firefox, galeon*/
    else
    {
        return Node.textContent;
    }
}

/**
 * @brief	Open a XML file, create and return XML DOM Tree
 *
 * @param	Url	XML file path
 * @return	XML DOM tree
 * @author 	Rubens Suguimoto
 */
function UTILS_OpenXMLFile(Url)
{
    var XML=null;
    var XMLDoc;

    // Code for Google Chromium, Code for Mozilla, Firefox, Opera, etc.
    if (window.XMLHttpRequest)
    {
        XML = new XMLHttpRequest();

    }
    // Code for IE
    //if (window.ActiveXObject)
    else
    {
        XML = new ActiveXObject("Microsoft.XMLHTTP");
    }


    // Use XMLHttpRequest to get document from server
    if(XML != null){
        // The "false" value is used to get file syncronous
        XML.open("GET",Url.split("?")[0],false);
        XML.send("");
        XMLDoc = XML.responseXML;
    }
    else
    {
        alert('Your browser doesn\'t support XML DOM.');
    }

    return(XMLDoc);
}

/**
 * @brief	Find and return node in XML tree with TagName and return this node content
 *
 * @param	XML		XML tree
 * @param	TagName 	String used to find node
 * @return	Node content string
 * @author 	Rubens Suguimoto
 */
function UTILS_GetTag(XML, TagName)
{
    var Node = XML.getElementsByTagName(TagName);

    // If dont find any tag
    if (Node == null)
    {
        return null;
    }
    // Return only first match
    else
    {
        Node = Node[0];
    }

    return UTILS_GetNodeText(Node);
}

/**
 * @brief	 Get text from language selected.
 * If TagName was not founded in language seleted, then found in Default language text.
 * We assume that default language has all tags.
 *
 * @param	TagName 	Text tag
 * @return	Text content of node with TagName
 * @author 	Rubens Suguimoto
 */
function UTILS_GetText(TagName)
{
    var Text = UTILS_GetTag(MainData.GetText(), TagName);
    var i=0;

    if(Text == null)
    {
        Text = UTILS_GetTag(MainData.GetDefaultText(), TagName);
    }

    Text = Text.replace(/\t/g,"").replace(/\n/g,"");

    return Text;
}

/**********************************
 * FUNCTIONS - AJAX AND SOAP
 ************************************/
/**
 * @brief This is a AJAX function to create a HTTP request, send and receive
 * response in SOAP format.
 *
 * @param message XML SOAP with invoke method
 * @param url URL to send request
 * @param parseResponseFunction Parse response function
 * @param SOAPAction SOAP Action to append in HTTP request Header
 *
 * @author Rubens Massayuki Suguimoto
 */
function ajax(message, url, parseResponseFunction, SOAPAction){
    var HttpRequest;

    /*Create XMLHttpRequest*/
    if(window.XMLHttpRequest)
    {
        /*Mozilla, Opera, Galeon*/
        HttpRequest = new XMLHttpRequest();
        if(HttpRequest.overrideMimeType)
        {
            HttpRequest.overrideMimeType("text/xml");
        }
    }
    else if (window.ActiveXObject)
    {
        /*Internet Explorer*/
        try
        {
            HttpRequest = new ActiveXObject("Microsoft.XMLHTTP");
        }
        catch(e)
        {
            HttpRequest = new ActiveXObject("Msxml2.XMLHTTP");
        }
    }

    /*Open a HTTP request method*/
    HttpRequest.open('POST',url, true);

    /*Set header encode*/
    HttpRequest.setRequestHeader("Content-Type",
            'text/xml; charset="UTF-8"');

    /*Set HTTP header SOAP Action*/
    HttpRequest.setRequestHeader("SOAPAction",SOAPAction);

    /*Set parse response function for request change state*/
    HttpRequest.onreadystatechange = function(){
        /*this function is parameter*/
        parseResponseFunction(HttpRequest, url);
    }

    /*Send request to server*/
    HttpRequest.send(message);
}

/**
 * @brief Create SOAP content with SOAP invoke method
 *
 * @param    SOAPAction      SOAP invoke method
 * @param    parameters      Array of method parameters
 * @param    parametersType  Array of method parameters type (XML Schemma
 * type)
 * @return   string (XML serialized)
 *
 * @author   Rubens Massayuki Suguimoto
 */
function makeSOAPContent(SOAPAction, parameters, parametersType)
{
    var xml = "";
    var i;

    xml += '<'+SOAPAction+' SOAP-ENC:root="1">';
    if (parameters != null)
    {
        for(i=0; i<parameters.length ; i++)
        {
            xml += '<v'+(i+1)+' type="'+parametersType[i]+'">';
            xml += parameters[i];
            xml += '</v'+(i+1)+'>';
        }
    }
    xml += '</'+SOAPAction+'>';

    return xml;
}

/**
 * @brief Create SOAP Envelope;
 *
 * @param SOAPContent    SOAP Body content
 * @return   string (XML serialized)
 *
 * @author   Rubens Massayuki Suguimoto
 */
function makeSOAPEnvelope(SOAPContent)
{
    var xml = "";

    xml += '<?xml version="1.0" encoding="UTF-8"?>';
    xml += '<SOAP-ENV:Envelope';
    xml += ' SOAP-ENV:encodingStyle="http://schemas.xmlsoap.org/soap/encoding/"';
    xml += ' xmlns:SOAP-ENC="http://schemas.xmlsoap.org/soap/encoding/"';
    xml += ' xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">';
    xml += '<SOAP-ENV:Body>';

    xml += SOAPContent;

    xml += '</SOAP-ENV:Body>';
    xml += '</SOAP-ENV:Envelope>';

    return xml;
}

/**********************************
 * FUNCTIONS - ERROR CHECKING
 ************************************/

/**
 * @brief Checks for errors in the creation of graphics
 *
 * @param response   Response text of HTTP response
 * @return   false No error
 * @return   true Have an error
 *
 * @author Renan Franca de Miranda
 */
function verifyError(resp)
{
    var i;
    var parent, child, loop;
    var regExp, error;

    regExp = new RegExp("Widget.ERROR_0001")
        error = false;

    if(regExp.test(resp))
    {
        error = true;
    }

    return error;
}
