/*
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of server
 *
 * server is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* Database libs */
import java.sql.*;
import org.postgresql.Driver;

/* File libs */
import java.io.*;

public class DBConnection {

/* Attributes */
Statement stmt = null;
public Connection myConnection;

/**
 * Database constructor.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              void
*/
public DBConnection() {
    super();
}

/**
 * Creates a new instance of data base connection.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              boolean
*/
public boolean connect()
throws ClassNotFoundException, SQLException, Exception {
    XmlUtil config = new XmlUtil("./seed2/conf.xml");
    String dbTag = "db_config";

    /* Get information from configuration file */
    String host = config.getTextValue(config.getTag(dbTag), "host");
    String port = config.getTextValue(config.getTag(dbTag), "port");
    String schema = config.getTextValue(config.getTag(dbTag), "schema");
    String user = config.getTextValue(config.getTag(dbTag), "user");
    String passwd = config.getTextValue(config.getTag(dbTag), "passwd");

    Driver.class.newInstance();

    System.out.println("DB: Driver Initialized.");

    /* Open connection to data base */
    myConnection = DriverManager.getConnection("jdbc:postgresql://" + host +
                    ":" + port + "/" + schema, user, passwd);

    System.out.println("DB: Connected to Database.");

    stmt = myConnection.createStatement();
    return true;
}

/**
 * Close connection with data base.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              void
*/
public void close() throws SQLException {
    stmt.close();
    myConnection.close();
}

/**
 * Execute query in data base.
 *
 * @author              Rubens Massayuki Suguimoto
 * @param       pSql    String
 * @return              ResultSet
*/
public ResultSet executeQuery(String pSql) throws SQLException {
    System.out.println("DB: Query: " + pSql);
    return stmt.executeQuery(pSql);
}

/**
 * Execute update query in data base.
 *
 * @author              Rubens Massayuki Suguimoto
 * @param       pSql    String
 * @return              int
*/
public int executeUpdate(String pSql) throws SQLException {
    System.out.println("DB: Update: " + pSql);
    return stmt.executeUpdate(pSql);
}

}
