/*
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of server
 *
 * server is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* XML Parser libs */
import org.apache.xerces.parsers.*;
import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

/* File libs */
import java.io.IOException;

public class Seed2Doc {

/* Attributes */
private String docFile;

/**
 * Seed2Doc service constructor.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              void
*/
public Seed2Doc() {
    XmlUtil docConf = new XmlUtil("./seed2/conf.xml");
    String docTag = "doc_config";

    /* Get information from configuration file */
    docFile = docConf.getTextValue(docConf.getTag(docTag),"doc_path");
}

/**
 * Return documents array.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              Seed2Document array
*/
public Seed2Document[] getDocuments() {
    int i;

    System.out.println("Doc: Opening:" + docFile);

    /* TODO - document array more flexible */
    Seed2Document [] docs = new Seed2Document[10];

    System.out.println("Doc: Parsing file.");
    XmlUtil docXml = new XmlUtil(docFile);
    System.out.println("Doc: Parse done.");

    NodeList docElements = docXml.getTags("document");

    for (i = 0; i < docElements.getLength(); i++) {
        Element docElement = (Element)docElements.item(i);
        docs[i] = getDocInfo(docElement);
    }

    return docs;
}

/**
 * Get document element information.
 *
 * @author               Rubens Massayuki Suguimoto
 * @param     docNode    Element (dom element)
 * @return               Seed2Document item
*/
private Seed2Document getDocInfo(Element docNode) {
        Seed2Document doc = new Seed2Document();
        XmlUtil parse = new XmlUtil();

        doc.Name = parse.getTextValue(docNode, "name");
        doc.Size = parse.getTextValue(docNode, "size");
        doc.Date = parse.getTextValue(docNode, "date");
        doc.URL = parse.getTextValue(docNode, "url");
        doc.Description = parse.getTextValue(docNode, "desc");

        return doc;
}

}
