/*
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of server
 *
 * server is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* General libs */
import java.util.*;
import java.text.*;

/* File libs */
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.FileInputStream;
import java.io.IOException;

/* Base 64 encoding */
import org.apache.axis.encoding.Base64;

public class Seed2Dump {

/* Attributes */
private String dumpPath;
private String dumpUpdateDate;

/**
 * Seed2Dump service constructor.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              void
*/
public Seed2Dump() {
    XmlUtil dumpConf = new XmlUtil("./seed2/conf.xml");
    String dumpTag = "dump_config";

    /* Get information from configuration file */
    this.dumpPath = dumpConf.getTextValue(dumpConf.getTag(dumpTag),
        "dump_path");
    this.dumpUpdateDate = dumpConf.getTextValue(dumpConf.getTag(dumpTag),
        "dump_update_date");
}


/**
 * Get database dump
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              String (base64 encoding)
*/
public String getDump() {
    try {
        System.out.println("DUMP: getDump: get file: " + this.dumpPath);

        /* Open dump file */
        File dumpFile = new File(this.dumpPath);

        if (!dumpFile.exists()) {
            return "DUMP: getDump: Dump file was not found.";
        }

        System.out.println("DUMP: getDump: reading dump file.");

        /* Return the dump file encoded in base64 */
	    return Base64.encode(getFileAsBytes(dumpFile));

    }
    catch (IOException e) {
        System.err.println(e);
        return null;
    }
}

/**
 * Return the last dump update date
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              String date
*/
public String getLastDumpDate(){

    /* Read file */
    try {
        System.out.println("DUMP: getLastDumpDate: opening file: "+
                            this.dumpUpdateDate);
        FileReader dumpUpdateFile = new FileReader(this.dumpUpdateDate);
        BufferedReader br = new BufferedReader(dumpUpdateFile);
        StringBuffer bufOutput = new StringBuffer();

        String line;
        /* Read lines of file */
        while( (line = br.readLine()) != null) {
            bufOutput.append(line);
        }

        /* Close buffer */
        br.close();

        /* Create regular expression object */
        String date = bufOutput.toString();

        return date;
    }
    catch (IOException e) {
        System.out.println("DUMP: getLastDumpDate: Invalid date or dump "+
                           "date file was not found.");
        return "Invalid date or dump date file was not found.";
    }
}

/**
 * Read a file as a byte array
 *
 * @author              Rubens Massayuki Suguimoto
 * @param   file        File object to read
 * @return              Byte array
*/
private final byte[] getFileAsBytes(final File file) throws IOException {
    final BufferedInputStream bis = new BufferedInputStream(
        new FileInputStream(file));
    final byte [] bytes = new byte[(int) file.length()];

    System.out.println("DUMP: getFileAsBytes: size: " + file.length());

    bis.read(bytes);
    bis.close();

    return bytes;
}

}
