/*
 * Copyright (C) 2009-2012 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
 *
 * This file is part of server
 *
 * server is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA.
 */

/* XML Parser libs */
import org.apache.xerces.parsers.*;
import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import org.w3c.dom.Node;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

/* File libs */
import java.io.IOException;

public class XmlUtil {

/* Attributes */
private Document document;

/**
 * XmlUtil constructor.
 *
 * @author              Rubens Massayuki Suguimoto
 * @return              void
*/
public XmlUtil() {
    document = null;
}

/**
 * XmlUtil constructor.
 *
 * @param     filePath    String
 * @author                Rubens Massayuki Suguimoto
 * @return                void
*/
public XmlUtil(String filePath) {
    DOMParser parser = new DOMParser();

    try {
        parser.parse(filePath);
    } catch (SAXException se) {
        se.printStackTrace();
    } catch (IOException ioe) {
        ioe.printStackTrace();
    }

    document = parser.getDocument();
}

/**
 * Get elements by tag name.
 *
 * @author               Rubens Massayuki Suguimoto
 * @param     tagName    String
 * @return               NodeList
*/
public NodeList getTags(String tagName) {
    return this.document.getElementsByTagName(tagName);
}

/**
 * Get the first element with tag name.
 *
 * @author                Rubens Massayuki Suguimoto
 * @param     tagName     String
 * @return                Element
*/
public Element getTag(String tagName) {
    NodeList tmp = this.document.getElementsByTagName(tagName);

    return (Element)tmp.item(0);
}

/**
 * Get node text by tag name.
 *
 * @author              Rubens Massayuki Suguimoto
 * @param   node        Element
 * @param   tagName     String
 * @return              String
*/
public String getTextValue(Element node, String tagName) {
    String textVal = null;
    NodeList nodeList = node.getElementsByTagName(tagName);
    if ((nodeList != null) && (nodeList.getLength() > 0)) {
        Element el = (Element)nodeList.item(0);
        textVal = el.getFirstChild().getNodeValue();
    }

    return textVal;
}

}
