package controllers;

import java.util.ArrayList;

import play.*;
import play.mvc.*;
import play.data.*;

import views.html.attendance.*;
import models.*;

public class Attendance extends Controller {

    public static Result index() {
        return redirect(controllers.routes.Attendance.availabilityBrasil("proinfo"));
    }

    public static Result school(Long id) throws java.sql.SQLException {
        School school = School.getById(id);

        return ok(views.html.attendance.school.render(school, null));
    }

    public static Result schoolByName() throws java.sql.SQLException {
        DynamicForm requestData = DynamicForm.form().bindFromRequest();
        String name = requestData.get("name");

        if (name == null)
            return badRequest("invalid name");

        School school = School.getByName(name);

        return ok(views.html.attendance.school.render(school, "network"));
    }

    public static Result searchSchool() throws java.sql.SQLException {
        DynamicForm requestData = DynamicForm.form().bindFromRequest();
        String query = requestData.get("query");
        String region = requestData.get("region");
        String state = requestData.get("state");
        String city = requestData.get("city");

        if ((query == null) || (query.length() == 0)) {
            return ok(views.html.attendance.searchSchool.render(null, null, null, null, null));
        }

        if ((region == null) || (region.length() == 0)) {
            ArrayList<SearchResult> results = SearchResult.getByQuery(query);
            return ok(views.html.attendance.searchSchool.render(query, null, null, null, results));
        }

        if ((state == null) || (state.length() == 0)) {
            ArrayList<SearchResult> results = SearchResult.getByQuery(query, region);
            return ok(views.html.attendance.searchSchool.render(query, region, null, null, results));
        }

        if ((city == null) || (city.length() == 0)) {
            ArrayList<SearchResult> results = SearchResult.getByQuery(query, region, state);
            return ok(views.html.attendance.searchSchool.render(query, region, state, null, results));
        }

        ArrayList<SearchResult> results = SearchResult.getByQuery(query, region, state, city);
        return ok(views.html.attendance.searchSchool.render(query, region, state, city, results));
    }

    public static Result searchReport() {
        return ok(views.html.attendance.searchReport.render());
    }



    public static Result availabilityBrasil(String project) {
        return ok(availability.render(project, null, null));
    }

    public static Result availabilityRegion(String project, String region) {
        return ok(availability.render(project, region, null));
    }

    public static Result availabilityState(String project, String region, String state) {
        return ok(availability.render(project, region, state));
    }


    public static Result inventoryBrasil(String project) {
        return ok(inventory.render(project, null, null));
    }

    public static Result inventoryRegion(String project, String region) {
        return ok(inventory.render(project, region, null));
    }

    public static Result inventoryState(String project, String region, String state) {
        return ok(inventory.render(project, region, state));
    }


    public static Result auditBrasil(String project) {
        return ok(audit.render(project, null, null));
    }

    public static Result auditRegion(String project, String region) {
        return ok(audit.render(project, region, null));
    }

    public static Result auditState(String project, String region, String state) {
        return ok(audit.render(project, region, state));
    }


    public static Result alertBrasil(String project) {
        return ok(alert.render(project, null, null));
    }

    public static Result alertRegion(String project, String region) {
        return ok(alert.render(project, region, null));
    }

    public static Result alertState(String project, String region, String state) {
        return ok(alert.render(project, region, state));
    }


    public static Result networkBrasil(String project) {
        return ok(network.render(project, null, null, null));
    }

    public static Result networkRegion(String project, String region) {
        return ok(network.render(project, region, null, null));
    }

    public static Result networkState(String project, String region, String state) {
        return ok(network.render(project, region, state, null));
    }

    public static Result networkCity(String project, String region, String state, String city) {
        return ok(network.render(project, region, state, city));
    }


    public static Result osBrasil(String project) {
        return ok(os.render(project, null, null));
    }
}
