package controllers;

import play.*;
import play.mvc.*;

import org.codehaus.jackson.JsonNode;
import play.mvc.BodyParser;

import models.*;

public class Data extends Controller {

    public static Result netUsage(Long schoolId) {
        NetUsage net;

        try {
            net = NetUsage.getBySchoolId(schoolId);
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return badRequest("SQL failed");
        }

        return ok(net.toJson()).as("application/json");
    }


    @BodyParser.Of(BodyParser.Json.class)
    public static Result availability() {
        JsonNode json = request().body().asJson();
        Availability avail;

        String type = json.findPath("type").getTextValue();
        String level = json.findPath("level").getTextValue();
        String project = json.findPath("project").getTextValue();
        String region = json.findPath("region").getTextValue();
        String state = json.findPath("state").getTextValue();

        if ((type == null) || (level == null) ||
            (project == null)) {
            return badRequest("Missing parameters");
        }

        try {
            if (level.equals("brazil")) {
                if (type.equals("current"))
                    avail = Availability.getCurrent(project);
                else if (type.equals("historical"))
                    avail = Availability.getHistorical(project);
                else if (type.equals("sub"))
                    avail = Availability.getCurrentRegions(project);
                else
                    return badRequest("Unknown type");

                return ok(avail.toJson()).as("application/json");
            }
            else if (level.equals("region")) {
                if (type.equals("current"))
                    avail = Availability.getCurrentByRegion(project, region);
                else if (type.equals("historical"))
                    avail = Availability.getHistoricalByRegion(project, region);
                else if (type.equals("sub"))
                    avail = Availability.getCurrentStatesByRegion(project, region);
                else
                    return badRequest("Unknown type");

                return ok(avail.toJson()).as("application/json");
            }
            else if (level.equals("state")) {
                if (type.equals("current"))
                    avail = Availability.getCurrentByState(project, region, state);
                else if (type.equals("historical"))
                    avail = Availability.getHistoricalByState(project, region, state);
                else if (type.equals("sub"))
                    avail = Availability.getCurrentCitiesByState(project, region, state);
                else
                    return badRequest("Unknown type");

                return ok(avail.toJson()).as("application/json");
            }
            else
                return badRequest("Unknown level");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return badRequest("SQL failed");
        }
    }

    @BodyParser.Of(BodyParser.Json.class)
    public static Result inventory() {
        JsonNode json = request().body().asJson();

        Inventory inv;

        String type = json.findPath("type").getTextValue();
        String level = json.findPath("level").getTextValue();
        String project = json.findPath("project").getTextValue();
        String region = json.findPath("region").getTextValue();
        String state = json.findPath("state").getTextValue();
        String city = json.findPath("city").getTextValue();

        if ((type == null) || (level == null) ||
            (project == null)) {
            return badRequest("Missing parameters");
        }

        try {
            if (level.equals("brazil")) {
                if (type.equals("current"))
                    inv = Inventory.getCurrent(project);
                else if (type.equals("historical"))
                    inv = Inventory.getHistorical(project);
                else if (type.equals("sub"))
                    inv = Inventory.getCurrentRegions(project);
                else
                    return badRequest("Unknown type");

                return ok(inv.toJson()).as("application/json");
            }
            else if (level.equals("region")) {
                if (type.equals("current"))
                    inv = Inventory.getCurrentByRegion(project, region);
                else if (type.equals("historical"))
                    inv = Inventory.getHistoricalByRegion(project, region);
                else if (type.equals("sub"))
                    inv = Inventory.getCurrentStatesByRegion(project, region);
                else
                    return badRequest("Unknown type");

                return ok(inv.toJson()).as("application/json");
            }
            else if (level.equals("state")) {
                if (type.equals("current"))
                    inv = Inventory.getCurrentByState(project, region, state);
                else if (type.equals("historical"))
                    inv = Inventory.getHistoricalByState(project, region, state);
                else if (type.equals("sub"))
                    inv = Inventory.getCurrentCitiesByState(project, region, state);
                else
                    return badRequest("Unknown type");

                return ok(inv.toJson()).as("application/json");
            }
            else if (level.equals("city")) {
                if (type.equals("current"))
                    inv = Inventory.getCurrentByCity(project, region, state, city);
                else if (type.equals("historical"))
                    inv = Inventory.getHistoricalByCity(project, region, state, city);
                else if (type.equals("sub"))
                    inv = Inventory.getCurrentSchoolsByCity(project, region, state, city);
                else
                    return badRequest("Unknown type");

                return ok(inv.toJson()).as("application/json");
            }
            else
                return badRequest("Unknown level");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return badRequest("SQL failed");
        }
    }

    @BodyParser.Of(BodyParser.Json.class)
    public static Result audit() {
        JsonNode json = request().body().asJson();

        Audit audit;

        String type = json.findPath("type").getTextValue();
        String level = json.findPath("level").getTextValue();
        String project = json.findPath("project").getTextValue();
        String region = json.findPath("region").getTextValue();
        String state = json.findPath("state").getTextValue();

        if ((type == null) || (level == null) ||
            (project == null)) {
            return badRequest("Missing parameters");
        }

        try {
            if (level.equals("brazil")) {
                if (type.equals("current"))
                    audit = Audit.getCurrent(project);
                else if (type.equals("historical"))
                    audit = Audit.getHistorical(project);
                else if (type.equals("sub"))
                    audit = Audit.getCurrentRegions(project);
                else
                    return badRequest("Unknown type");

                return ok(audit.toJson()).as("application/json");
            }
            else if (level.equals("region")) {
                if (type.equals("current"))
                    audit = Audit.getCurrentByRegion(project, region);
                else if (type.equals("historical"))
                    audit = Audit.getHistoricalByRegion(project, region);
                else if (type.equals("sub"))
                    audit = Audit.getCurrentStatesByRegion(project, region);
                else
                    return badRequest("Unknown type");

                return ok(audit.toJson()).as("application/json");
            }
            else if (level.equals("state")) {
                if (type.equals("current"))
                    audit = Audit.getCurrentByState(project, region, state);
                else if (type.equals("historical"))
                    audit = Audit.getHistoricalByState(project, region, state);
                else if (type.equals("sub"))
                    audit = Audit.getCurrentCitiesByState(project, region, state);
                else
                    return badRequest("Unknown type");

                return ok(audit.toJson()).as("application/json");
            }
            else
                return badRequest("Unknown level");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return badRequest("SQL failed");
        }
    }

    @BodyParser.Of(BodyParser.Json.class)
    public static Result alert() {
        JsonNode json = request().body().asJson();

        Alert alert;

        String type = json.findPath("type").getTextValue();
        String level = json.findPath("level").getTextValue();
        String project = json.findPath("project").getTextValue();
        String region = json.findPath("region").getTextValue();
        String state = json.findPath("state").getTextValue();

        if ((type == null) || (level == null) ||
            (project == null)) {
            return badRequest("Missing parameters");
        }

        try {
            if (level.equals("brazil")) {
                if (type.equals("current"))
                    alert = Alert.getCurrent(project);
                else if (type.equals("historical"))
                    alert = Alert.getHistorical(project);
                else if (type.equals("sub"))
                    alert = Alert.getCurrentRegions(project);
                else
                    return badRequest("Unknown type");

                return ok(alert.toJson()).as("application/json");
            }
            else if (level.equals("region")) {
                if (type.equals("current"))
                    alert = Alert.getCurrentByRegion(project, region);
                else if (type.equals("historical"))
                    alert = Alert.getHistoricalByRegion(project, region);
                else if (type.equals("sub"))
                    alert = Alert.getCurrentStatesByRegion(project, region);
                else
                    return badRequest("Unknown type");

                return ok(alert.toJson()).as("application/json");
            }
            else if (level.equals("state")) {
                if (type.equals("current"))
                    alert = Alert.getCurrentByState(project, region, state);
                else if (type.equals("historical"))
                    alert = Alert.getHistoricalByState(project, region, state);
                else if (type.equals("sub"))
                    alert = Alert.getCurrentCitiesByState(project, region, state);
                else
                    return badRequest("Unknown type");

                return ok(alert.toJson()).as("application/json");
            }
            else
                return badRequest("Unknown level");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return badRequest("SQL failed");
        }
    }

    @BodyParser.Of(BodyParser.Json.class)
    public static Result os() {
        JsonNode json = request().body().asJson();

        OS os;

        String type = json.findPath("type").getTextValue();
        String project = json.findPath("project").getTextValue();

        if ((type == null) || (project == null)) {
            return badRequest("Missing parameters");
        }

        try {
            if (type.equals("current"))
                os = OS.getCurrent(project);
            else if (type.equals("historical"))
                os = OS.getHistorical(project);
            else
                return badRequest("Unknown type");

            return ok(os.toJson()).as("application/json");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return badRequest("SQL failed");
        }
    }

}
