package controllers;

import java.io.*;
import java.util.ArrayList;

import play.*;
import play.mvc.*;
import play.data.*;
import play.mvc.Http.MultipartFormData;
import play.mvc.Http.MultipartFormData.FilePart;

import models.*;

public class SaveConfig extends Controller {

    private static long MAX_FILE_LENGTH = 10 * 1024 * 1024;

    public static Result get(String inep, String macaddr) {
        try {
            if (!School.checkMachineBelongsToSchool(inep, macaddr))
                return forbidden("You do not have permission to access this file.");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return internalServerError("Authentication failure.");
        }

        String filename = "config_"+inep+".tar.bz2";
        InputStream in = SavedConfig.get(inep);

        if (in == null)
            return notFound();

        response().setHeader("Content-Disposition", "attachment; filename="+filename);
        return ok(in);
    }

    public static Result put(String inep, String macaddr) {
        try {
            if (!School.checkMachineBelongsToSchool(inep, macaddr))
                return forbidden("You do not have permission to access this file.");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return internalServerError("Authentication failure.");
        }

        try {
            MultipartFormData body = request().body().asMultipartFormData();

            FilePart uploadPart = body.getFile("config");
            if (uploadPart == null)
                throw new Exception("Failed to upload configuration.");

            File uploadFile = uploadPart.getFile();
            if (uploadFile == null)
                throw new Exception("Failed to upload configuration.");

            if (uploadFile.length() > MAX_FILE_LENGTH)
                throw new Exception("Configuration file is too large (>10MB).");

            InputStream src = new FileInputStream(uploadFile);

            if ( ! SavedConfig.put(inep, src, uploadFile.length()) )
                throw new Exception("Failure to save configuration to the database.");
        }
        catch (Exception e) {
            e.printStackTrace();
            return internalServerError(e.getMessage());
        }

        return ok(); // no news is good news
    }

    public static Result exists(String inep, String macaddr) {
        try {
            if (!School.checkMachineBelongsToSchool(inep, macaddr))
                return forbidden("You do not have permission to access this file.");
        }
        catch (java.sql.SQLException e) {
            e.printStackTrace();
            return internalServerError("Authentication failure.");
        }

        if (SavedConfig.exists(inep))
            return ok("true");
        else
            return ok("false");
    }

}
