package models;

import java.util.ArrayList;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class Alert implements java.io.Serializable {
    private static final long serialVersionUID = -5477084817752317906L;

    private ArrayList<String> categories;
    private ArrayList<Long> hd;
    private ArrayList<Long> mem;

    public Alert() {
        this.categories = new ArrayList<String>();
        this.hd = new ArrayList<Long>();
        this.mem = new ArrayList<Long>();
    }

    public void addRow(String category, Long hd, Long mem) {
        this.categories.add(category);
        this.hd.add(hd);
        this.mem.add(mem);
    }

    public ObjectNode toJson() {
        ObjectNode result = Json.newObject();

        result.put("categories", Json.toJson(this.categories));
        result.put("hd", Json.toJson(this.hd));
        result.put("mem", Json.toJson(this.mem));

        return result;
    }

    public static Alert getCurrent(String project) throws SQLException {
        Alert alert = (Alert) Cache.get("alertCurrent"+project);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_brazil(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long hd = res.getLong(1);
                Long mem = res.getLong(2);

                alert.addRow(date.toString(), hd, mem);
            }

            Cache.set("alertCurrent"+project, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getHistorical(String project) throws SQLException {
        Alert alert = (Alert) Cache.get("alertHistorical"+project);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_brazil_monthly_history(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                String date = res.getString(1);
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(date, hd, mem);
            }

            Cache.set("alertHistorical"+project, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getCurrentRegions(String project) throws SQLException {
        Alert alert = (Alert) Cache.get("alertCurrentRegions"+project);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_region(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                String region = res.getString(1);
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(region, hd, mem);
            }

            Cache.set("alertCurrentRegions"+project, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getCurrentByRegion(String project, String region) throws SQLException {
        Alert alert = (Alert) Cache.get("alertCurrentByRegion"+project+region);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_region(?::project_enum) WHERE \"region\"=?;");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(date.toString(), hd, mem);
            }

            Cache.set("alertCurrentByRegion"+project+region, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getHistoricalByRegion(String project, String region) throws SQLException {
        Alert alert = (Alert) Cache.get("alertHistoricalByRegion"+project+region);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_region_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                String date = res.getString(1);
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(date, hd, mem);
            }

            Cache.set("alertHistoricalByRegion"+project+region, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getCurrentStatesByRegion(String project, String region) throws SQLException {
        Alert alert = (Alert) Cache.get("alertCurrentStatesByRegion"+project+region);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_state(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                String state = res.getString(1);
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(state, hd, mem);
            }

            Cache.set("alertCurrentStatesByRegion"+project+region, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getCurrentByState(String project, String region, String state) throws SQLException {
        Alert alert = (Alert) Cache.get("alertCurrentByState"+project+region+state);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_state(?::project_enum, ?) WHERE \"state\"=?;");
            st.setString(1, project);
            st.setString(2, region);
            st.setString(3, state);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(date.toString(), hd, mem);
            }

            Cache.set("alertCurrentByState"+project+region+state, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getHistoricalByState(String project, String region, String state) throws SQLException {
        Alert alert = (Alert) Cache.get("alertHistoricalByState"+project+region+state);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_state_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                String date = res.getString(1);
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(date, hd, mem);
            }

            Cache.set("alertHistoricalByState"+project+region+state, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }

    public static Alert getCurrentCitiesByState(String project, String region, String state) throws SQLException {
        Alert alert = (Alert) Cache.get("alertCurrentCitiesByState"+project+region+state);

        if (alert != null)
            return alert;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM alert_city(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            alert = new Alert();

            while (res.next()) {
                String city = res.getString(1);
                Long hd = res.getLong(2);
                Long mem = res.getLong(3);

                alert.addRow(city, hd, mem);
            }

            Cache.set("alertCurrentCitiesByState"+project+region+state, alert);
        }
        finally {
            conn.close();
        }

        return alert;
    }


}
