package models;

import java.util.ArrayList;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class Audit implements java.io.Serializable {
    private static final long serialVersionUID = -83324031927622850L;

    private ArrayList<String> categories;
    private ArrayList<Long> installed;
    private ArrayList<Long> notInstalled;

    public Audit() {
        this.categories = new ArrayList<String>();
        this.installed = new ArrayList<Long>();
        this.notInstalled = new ArrayList<Long>();
    }

    public void addRow(String category, Long installed, Long notInstalled) {
        this.categories.add(category);
        this.installed.add(installed);
        this.notInstalled.add(notInstalled);
    }

    public ObjectNode toJson() {
        ObjectNode result = Json.newObject();

        result.put("categories", Json.toJson(this.categories));
        result.put("installed", Json.toJson(this.installed));
        result.put("notInstalled", Json.toJson(this.notInstalled));

        return result;
    }

    public static Audit getCurrent(String project) throws SQLException {
        Audit audit = (Audit) Cache.get("auditCurrent"+project);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_brazil(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long installed = res.getLong(1);
                //Long notInstalled = res.getLong(2);
                Long notInstalled = 0L;

                audit.addRow(date.toString(), installed, notInstalled);
            }

            Cache.set("auditCurrent"+project, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getHistorical(String project) throws SQLException {
        Audit audit = (Audit) Cache.get("auditHistorical"+project);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_brazil_monthly_history(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                String date = res.getString(1);
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(date, installed, notInstalled);
            }

            Cache.set("auditHistorical"+project, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getCurrentRegions(String project) throws SQLException {
        Audit audit = (Audit) Cache.get("auditCurrentRegions"+project);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_region(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                String region = res.getString(1);
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(region, installed, notInstalled);
            }

            Cache.set("auditCurrentRegions"+project, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getCurrentByRegion(String project, String region) throws SQLException {
        Audit audit = (Audit) Cache.get("auditCurrentByRegion"+project+region);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_region(?::project_enum) WHERE \"Regio\"=?;");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(date.toString(), installed, notInstalled);
            }

            Cache.set("auditCurrentByRegion"+project+region, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getHistoricalByRegion(String project, String region) throws SQLException {
        Audit audit = (Audit) Cache.get("auditHistoricalByRegion"+project+region);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_region_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                String date = res.getString(1);
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(date, installed, notInstalled);
            }

            Cache.set("auditHistoricalByRegion"+project+region, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getCurrentStatesByRegion(String project, String region) throws SQLException {
        Audit audit = (Audit) Cache.get("auditCurrentStatesByRegion"+project+region);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_state(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                String state = res.getString(1);
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(state, installed, notInstalled);
            }

            Cache.set("auditCurrentStatesByRegion"+project+region, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getCurrentByState(String project, String region, String state) throws SQLException {
        Audit audit = (Audit) Cache.get("auditCurrentByState"+project+region+state);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_state(?::project_enum, ?) WHERE \"Estado\"=?;");
            st.setString(1, project);
            st.setString(2, region);
            st.setString(3, state);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(date.toString(), installed, notInstalled);
            }

            Cache.set("auditCurrentByState"+project+region+state, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getHistoricalByState(String project, String region, String state) throws SQLException {
        Audit audit = (Audit) Cache.get("auditHistoricalByState"+project+region+state);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_state_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                String date = res.getString(1);
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(date, installed, notInstalled);
            }

            Cache.set("auditHistoricalByState"+project+region+state, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }

    public static Audit getCurrentCitiesByState(String project, String region, String state) throws SQLException {
        Audit audit = (Audit) Cache.get("auditCurrentCitiesByState"+project+region+state);

        if (audit != null)
            return audit;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_city(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            audit = new Audit();

            while (res.next()) {
                String city = res.getString(1);
                Long installed = res.getLong(2);
                //Long notInstalled = res.getLong(3);
                Long notInstalled = 0L;

                audit.addRow(city, installed, notInstalled);
            }

            Cache.set("auditCurrentCitiesByState"+project+region+state, audit);
        }
        finally {
            conn.close();
        }

        return audit;
    }


}
