package models;

import java.util.ArrayList;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class Availability implements java.io.Serializable {
    private static final long serialVersionUID = -79175334936007860L;

    private ArrayList<String> categories;
    private ArrayList<Long> green;
    private ArrayList<Long> yellow;
    private ArrayList<Long> red;

    public Availability() {
        this.categories = new ArrayList<String>();
        this.green = new ArrayList<Long>();
        this.yellow = new ArrayList<Long>();
        this.red = new ArrayList<Long>();
    }

    public void addRow(String category, Long green, Long yellow, Long red) {
        this.categories.add(category);
        this.green.add(green);
        this.yellow.add(yellow);
        this.red.add(red);
    }

    public ObjectNode toJson() {
        ObjectNode result = Json.newObject();

        result.put("categories", Json.toJson(this.categories));
        result.put("green", Json.toJson(this.green));
        result.put("yellow", Json.toJson(this.yellow));
        result.put("red", Json.toJson(this.red));

        return result;
    }

    public static Availability getCurrent(String project) throws SQLException {
        Availability avail = (Availability) Cache.get("availCurrent"+project);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_brazil(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long green = res.getLong(1);
                Long yellow = res.getLong(2);
                Long red = res.getLong(3);

                avail.addRow(date.toString(), green, yellow, red);
            }

            Cache.set("availCurrent"+project, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getHistorical(String project) throws SQLException {
        Availability avail = (Availability) Cache.get("availHistorical"+project);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_brazil_monthly_history(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                String date = res.getString(1);
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(date, green, yellow, red);
            }

            Cache.set("availHistorical"+project, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getCurrentRegions(String project) throws SQLException {
        Availability avail = (Availability) Cache.get("availCurrentRegions"+project);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_region(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                String region = res.getString(1);
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(region, green, yellow, red);
            }

            Cache.set("availCurrentRegions"+project, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getCurrentByRegion(String project, String region) throws SQLException {
        Availability avail = (Availability) Cache.get("availCurrentByRegion"+project+region);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_region(?::project_enum) WHERE \"Regio\"=?;");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(date.toString(), green, yellow, red);
            }

            Cache.set("availCurrentByRegion"+project+region, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getHistoricalByRegion(String project, String region) throws SQLException {
        Availability avail = (Availability) Cache.get("availHistoricalByRegion"+project+region);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_region_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                String date = res.getString(1);
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(date, green, yellow, red);
            }

            Cache.set("availHistoricalByRegion"+project+region, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getCurrentStatesByRegion(String project, String region) throws SQLException {
        Availability avail = (Availability) Cache.get("availCurrentStatesByRegion"+project+region);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_state(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                String state = res.getString(1);
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(state, green, yellow, red);
            }

            Cache.set("availCurrentStatesByRegion"+project+region, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getCurrentByState(String project, String region, String state) throws SQLException {
        Availability avail = (Availability) Cache.get("availCurrentByState"+project+region+state);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_state(?::project_enum, ?) WHERE \"Estado\"=?;");
            st.setString(1, project);
            st.setString(2, region);
            st.setString(3, state);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(date.toString(), green, yellow, red);
            }

            Cache.set("availCurrentByState"+project+region+state, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getHistoricalByState(String project, String region, String state) throws SQLException {
        Availability avail = (Availability) Cache.get("availHistoricalByState"+project+region+state);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_state_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                String date = res.getString(1);
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(date, green, yellow, red);
            }

            Cache.set("availHistoricalByState"+project+region+state, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }

    public static Availability getCurrentCitiesByState(String project, String region, String state) throws SQLException {
        Availability avail = (Availability) Cache.get("availCurrentCitiesByState"+project+region+state);

        if (avail != null)
            return avail;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM availability_city(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            avail = new Availability();

            while (res.next()) {
                String city = res.getString(1);
                Long green = res.getLong(2);
                Long yellow = res.getLong(3);
                Long red = res.getLong(4);

                avail.addRow(city, green, yellow, red);
            }

            Cache.set("availCurrentCitiesByState"+project+region+state, avail);
        }
        finally {
            conn.close();
        }

        return avail;
    }


}
