package models;

import java.util.*;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.*;

public class ComboOptions implements java.io.Serializable {
    private static final long serialVersionUID = -25441369670443236L;

    private ArrayList<Map> options;

    public ComboOptions() {
        this.options = new ArrayList<Map>();
    }

    public void addRow(String value, String content) {
        HashMap<String,String> map = new HashMap<String,String>();
        map.put("value", value);
        map.put("content", content);
        this.options.add(map);
    }

    public JsonNode toJson() {
        return Json.toJson(this.options);
    }

    public ArrayList<Map> toList() {
        return this.options;
    }

    public static ComboOptions getRegions() throws SQLException {
        ComboOptions options = (ComboOptions) Cache.get("comboOptionsRegions");

        if (options != null)
            return options;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT DISTINCT(cit.region) FROM search_school s, dim_school sch, dim_city cit " +
                    " WHERE s.contacted_once='true' " +
                    "  AND sch.id = s.sch_id AND cit.id = sch.cit_id ORDER BY cit.region ASC;"
                    );

            ResultSet res = st.executeQuery();

            options = new ComboOptions();

            while (res.next()) {
                String region = res.getString(1);

                options.addRow(region, region);
            }

            Cache.set("comboOptionsRegions", options);
        }
        finally {
            conn.close();
        }

        return options;
    }

    public static ComboOptions getStates(String region) throws SQLException {
        ComboOptions options = (ComboOptions) Cache.get("comboOptionsStates"+region);

        if (options != null)
            return options;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT DISTINCT(cit.state) FROM search_school s, dim_school sch, dim_city cit " +
                    " WHERE s.contacted_once='true' AND cit.region=? " +
                    "  AND sch.id = s.sch_id AND cit.id = sch.cit_id ORDER BY cit.state ASC;"
                    );
            st.setString(1, region);

            ResultSet res = st.executeQuery();

            options = new ComboOptions();

            while (res.next()) {
                String state = res.getString(1);

                options.addRow(state, state);
            }

            Cache.set("comboOptionsStates"+region, options);
        }
        finally {
            conn.close();
        }

        return options;
    }

    public static ComboOptions getCities(String state) throws SQLException {
        ComboOptions options = (ComboOptions) Cache.get("comboOptionsCities"+state);

        if (options != null)
            return options;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT DISTINCT(cit.id),cit.name FROM search_school s, dim_school sch, dim_city cit " +
                    " WHERE s.contacted_once='true' AND cit.state=? " +
                    "  AND sch.id = s.sch_id AND cit.id = sch.cit_id ORDER BY cit.name ASC;"
                    );
            st.setString(1, state);

            ResultSet res = st.executeQuery();

            options = new ComboOptions();

            while (res.next()) {
                Long id = res.getLong(1);
                String city = res.getString(2);

                options.addRow(city, city);
            }

            Cache.set("comboOptionsCities"+state, options);
        }
        finally {
            conn.close();
        }

        return options;
    }

}
