package models;

import java.util.ArrayList;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class Inventory implements java.io.Serializable {
    private static final long serialVersionUID = 45845868997275830L;

    private ArrayList<String> categories;
    private ArrayList<Long> total;

    public Inventory() {
        this.categories = new ArrayList<String>();
        this.total = new ArrayList<Long>();
    }

    public void addRow(String category, Long total) {
        this.categories.add(category);
        this.total.add(total);
    }

    public ObjectNode toJson() {
        ObjectNode result = Json.newObject();

        result.put("categories", Json.toJson(this.categories));
        result.put("total", Json.toJson(this.total));

        return result;
    }

    public static Inventory getCurrent(String project) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrent"+project);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_brazil(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long total = res.getLong(1);

                inv.addRow(date.toString(), total);
            }

            Cache.set("invCurrent"+project, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getHistorical(String project) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invHistorical"+project);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_brazil_monthly_history(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String date = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(date, total);
            }

            Cache.set("invHistorical"+project, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentRegions(String project) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentRegions"+project);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_region(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String region = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(region, total);
            }

            Cache.set("invCurrentRegions"+project, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentByRegion(String project, String region) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentByRegion"+project+region);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_region(?::project_enum) WHERE \"Regio\"=?;");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long total = res.getLong(2);

                inv.addRow(date.toString(), total);
            }

            Cache.set("invCurrentByRegion"+project+region, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getHistoricalByRegion(String project, String region) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invHistoricalByRegion"+project+region);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_region_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String date = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(date, total);
            }

            Cache.set("invHistoricalByRegion"+project+region, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentStatesByRegion(String project, String region) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentStatesByRegion"+project+region);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_state(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String state = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(state, total);
            }

            Cache.set("invCurrentStatesByRegion"+project+region, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentByState(String project, String region, String state) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentByState"+project+region+state);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_state(?::project_enum, ?) WHERE \"Estado\"=?;");
            st.setString(1, project);
            st.setString(2, region);
            st.setString(3, state);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long total = res.getLong(2);

                inv.addRow(date.toString(), total);
            }

            Cache.set("invCurrentByState"+project+region+state, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getHistoricalByState(String project, String region, String state) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invHistoricalByState"+project+region+state);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_state_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String date = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(date, total);
            }

            Cache.set("invHistoricalByState"+project+region+state, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentCitiesByState(String project, String region, String state) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentCitiesByState"+project+region+state);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM inventory_city(?::project_enum, ?);");
            st.setString(1, project);
            st.setString(2, state);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String city = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(city, total);
            }

            Cache.set("invCurrentCitiesByState"+project+region+state, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentSchoolsByCity(String project, String region, String state, String city) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentSchoolsByCity"+project+region+state+city);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT s.name, count(distinct(f.macaddr)) FROM fact_contact f, dim_school s, dim_city c " +
                    "WHERE s.id=f.sch_id AND c.id=s.cit_id AND f.project=?::project_enum AND c.region=? AND c.state=? AND c.name=? " +
                    "GROUP BY s.id, s.name;");
            st.setString(1, project);
            st.setString(2, region);
            st.setString(3, state);
            st.setString(4, city);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                String school = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(school, total);
            }

            Cache.set("invCurrentSchoolsByCity"+project+region+state+city, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getCurrentByCity(String project, String region, String state, String city) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invCurrentByCity"+project+region+state+city);

        if (inv != null)
            return inv;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT count(distinct(f.sch_id)) FROM fact_contact f, dim_city c " +
                    "WHERE c.id=f.cit_id AND f.project=? AND c.region=? AND c.state=? AND c.name=?;");
            st.setString(1, project);
            st.setString(2, region);
            st.setString(3, state);
            st.setString(4, city);

            ResultSet res = st.executeQuery();

            inv = new Inventory();

            while (res.next()) {
                java.sql.Date date = new java.sql.Date(new java.util.Date().getTime());
                Long total = res.getLong(2);

                inv.addRow(date.toString(), total);
            }

            Cache.set("invCurrentByCity"+project+region+state+city, inv);
        }
        finally {
            conn.close();
        }

        return inv;
    }

    public static Inventory getHistoricalByCity(String project, String region, String state, String city) throws SQLException {
        Inventory inv = (Inventory) Cache.get("invHistoricalByCity"+project+region+state+city);

        if (inv != null)
            return inv;

        //Connection conn = DB.getConnection();

        try {
            /*PreparedStatement st = conn.prepareStatement(
                    "SELECT * FROM inventory_city_monthly_history(?::project_enum, ?);");
            st.setString(1, project);
            st.setInt(2, cityId);

            ResultSet res = st.executeQuery();*/

            inv = new Inventory();

            /*while (res.next()) {
                String date = res.getString(1);
                Long total = res.getLong(2);

                inv.addRow(date, total);
            }*/

            //Cache.set("invHistoricalByCity"+project+region+state+city, inv);
        }
        finally {
            //conn.close();
        }

        return inv;
    }
}
