package models;

import java.util.ArrayList;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class NetUsage implements java.io.Serializable {
    private static final long serialVersionUID = -98555947747081520L;

    private ArrayList<Long[]> download;
    private ArrayList<Long[]> upload;

    public NetUsage() {
        this.download = new ArrayList<Long[]>();
        this.upload = new ArrayList<Long[]>();
    }

    public void addRow(Long timestamp, Long download, Long upload) {
        this.download.add(new Long[] {timestamp, download});
        this.upload.add(new Long[] {timestamp, upload});
    }

    public ObjectNode toJson() {
        ObjectNode result = Json.newObject();

        result.put("download", Json.toJson(this.download));
        result.put("upload", Json.toJson(this.upload));

        return result;
    }

    public static NetUsage getBySchoolId(Long id) throws SQLException {
        NetUsage net = (NetUsage) Cache.get("netUsage"+id);

        if (net != null)
            return net;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT (dat_id + collect_time - interval '00:02:30'), " +
                    " (sum(down_kbits)/300)::bigint, (sum(up_kbits)/300)::bigint " +
                    "FROM fact_net_usage " +
                    "WHERE sch_id=? AND dat_id > (current_date - interval '6 months') " +
                    "GROUP BY sch_id, dat_id, collect_time " +
                    "ORDER BY dat_id, collect_time ASC;");
            st.setLong(1, id);

            ResultSet res = st.executeQuery();

            net = new NetUsage();

            while (res.next()) {
                java.sql.Timestamp timestamp = res.getTimestamp(1);
                Long download = res.getLong(2);
                Long upload = res.getLong(3);

                net.addRow(timestamp.getTime(), download, upload);
            }

            Cache.set("netUsage"+id, net);
        }
        finally {
            conn.close();
        }

        return net;
    }

}
