package models;

import java.util.*;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.*;

public class OS implements java.io.Serializable {
    private static final long serialVersionUID = -79175334936007860L;

    private List<Map<String,Object>> items;

    public OS() {
        this.items = new ArrayList<Map<String,Object>>();
    }

    public void addRow(String os, String date, Long count) {
        Map<String, Object> row = null;

        for (Map<String, Object> r : this.items) {
            if (r.get("name").equals(os)) {
                row = r;
                break;
            }
        }

        if (row == null) {
            row = new HashMap<String, Object>();
            row.put("name", os);
            row.put("data", new ArrayList<String[]>());
            this.items.add(row);
        }

        List<String[]> list = (List) row.get("data");
        list.add(new String[] {date, count.toString()});
    }

    public JsonNode toJson() {
        return Json.toJson(this.items);
    }

    public static OS getCurrent(String project) throws SQLException {
        OS os = (OS) Cache.get("osCurrent"+project);

        if (os != null)
            return os;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM os_brazil(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            os = new OS();

            while (res.next()) {
                String date = String.valueOf(new java.util.Date().getTime());
                String osName = res.getString(1);
                Long count = res.getLong(2);

                os.addRow(osName, date, count);
            }

            Cache.set("osCurrent"+project, os);
        }
        finally {
            conn.close();
        }

        return os;
    }

    public static OS getHistorical(String project) throws SQLException {
        OS os = (OS) Cache.get("osHistorical"+project);

        if (os != null)
            return os;

        Connection conn = DB.getConnection();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT * FROM os_brazil_monthly_history(?::project_enum);");
            st.setString(1, project);

            ResultSet res = st.executeQuery();

            os = new OS();

            while (res.next()) {
                String date = String.valueOf(res.getTimestamp(1).getTime());
                String osName = res.getString(2);
                Long count = res.getLong(3);

                os.addRow(osName, date, count);
            }

            Cache.set("osHistorical"+project, os);
        }
        finally {
            conn.close();
        }

        return os;
    }
}
