package models;

import java.util.ArrayList;
import java.sql.*;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class School implements java.io.Serializable {
    private static final long serialVersionUID = -11377209587953984L;

    public Long id;
    public String name;
    public String city;
    public String state;

    public ArrayList<Machine> getMachines() throws SQLException {
        return Machine.getMachinesBySchoolId(this.id);
    }

    public String getLastContactDate() throws SQLException {
        Connection conn = DB.getConnection();
        String date = "";

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT max(dat_id) FROM fact_contact WHERE sch_id=?;");
            st.setLong(1, this.id);

            ResultSet res = st.executeQuery();

            if (res.next()) {
                DateFormat df = new SimpleDateFormat("dd/MM/yyyy");
                date = df.format(res.getDate(1));
            }
            else
                date = "nunca";
        }
        finally {
            conn.close();
        }

        return date;
    }

    public static School getById(Long id) throws SQLException {
        Connection conn = DB.getConnection();
        School school = null;

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT sch.id, sch.name, initcap(cit.name),cit.state " +
                    "FROM dim_school sch, dim_city cit " +
                    "WHERE sch.id = ? AND cit.id = sch.cit_id;");
            st.setLong(1, id);

            ResultSet res = st.executeQuery();

            if (!res.next())
                throw new SQLException("School not found");

            school = new School();

            school.id = res.getLong(1);
            school.name = res.getString(2);
            school.city = res.getString(3);
            school.state = res.getString(4);

        }
        finally {
            conn.close();
        }

        return school;
    }

    public static School getByInep(String inep) throws SQLException {
        Connection conn = DB.getConnection();
        School school = null;

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT sch.id, sch.name, initcap(cit.name), cit.state " +
                    "FROM dim_school sch, dim_city cit " +
                    "WHERE sch.inep = ? AND cit.id = sch.cit_id;");
            st.setString(1, inep);

            ResultSet res = st.executeQuery();

            if (res.next()) {
                school = new School();

                school.id = res.getLong(1);
                school.name = res.getString(2);
                school.city = res.getString(3);
                school.state = res.getString(4);
            }
        }
        finally {
            conn.close();
        }

        return school;
    }

    public static School getByName(String name) throws SQLException {
        Connection conn = DB.getConnection();
        School school = null;

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT sch.id, sch.name, initcap(cit.name),cit.state " +
                    "FROM dim_school sch, dim_city cit " +
                    "WHERE sch.name = ? AND cit.id = sch.cit_id;");
            st.setString(1, name);

            ResultSet res = st.executeQuery();

            if (!res.next())
                throw new SQLException("School not found");

            school = new School();

            school.id = res.getLong(1);
            school.name = res.getString(2);
            school.city = res.getString(3);
            school.state = res.getString(4);

        }
        finally {
            conn.close();
        }

        return school;
    }

    public static boolean checkMachineBelongsToSchool(String inep, String macaddr) throws SQLException {
        Connection conn = DB.getConnection();
        boolean found = false;

        try {
            PreparedStatement st = conn.prepareStatement(
                    "SELECT 1 FROM dim_school sch, dim_inventory inv " +
                    "WHERE inv.sch_id=sch.id AND sch.inep=? and inv.macaddr=? " +
                    "GROUP BY inv.macaddr;");
            st.setString(1, inep);
            org.postgresql.util.PGobject macaddrobj = new org.postgresql.util.PGobject();
            macaddrobj.setType("macaddr");
            macaddrobj.setValue(macaddr);
            st.setObject(2, macaddrobj);

            ResultSet res = st.executeQuery();

            if (res.next())
                found = true;
        }
        finally {
            conn.close();
        }

        return found;
    }
}
