package models;

import java.util.ArrayList;
import java.sql.*;

import play.db.*;
import play.libs.Json;
import play.cache.Cache;

import org.codehaus.jackson.node.*;

public class SearchResult implements java.io.Serializable {
    private static final long serialVersionUID = -89665216859430080L;

    public Long id;
    public String name;
    public String city;

    public SearchResult(Long id, String name, String city) {
        this.id = id;
        this.name = name;
        this.city = city;
    }

    public ObjectNode toJson() {
        ObjectNode result = Json.newObject();

        result.put("id", Json.toJson(this.id));
        result.put("name", Json.toJson(this.name));
        result.put("city", Json.toJson(this.city));

        return result;
    }

    public static ArrayList<SearchResult> getByQuery(String query, String region, String state, String city) throws SQLException {
        Connection conn = DB.getConnection();

        ArrayList<SearchResult> results = new ArrayList<SearchResult>();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT id,name,city FROM do_search_school(?) WHERE region=? AND state=? AND city_raw=?;");
            st.setString(1, query);
            st.setString(2, region);
            st.setString(3, state);
            st.setString(4, city);

            ResultSet res = st.executeQuery();

            while (res.next()) {
                Long id = res.getLong(1);
                String name = res.getString(2);
                String ret_city = res.getString(3);

                results.add(new SearchResult(id, name, ret_city));
            }

        }
        finally {
            conn.close();
        }

        return results;
    }

    public static ArrayList<SearchResult> getByQuery(String query, String region, String state) throws SQLException {
        Connection conn = DB.getConnection();

        ArrayList<SearchResult> results = new ArrayList<SearchResult>();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT id,name,city FROM do_search_school(?) WHERE region=? AND state=?;");
            st.setString(1, query);
            st.setString(2, region);
            st.setString(3, state);

            ResultSet res = st.executeQuery();

            while (res.next()) {
                Long id = res.getLong(1);
                String name = res.getString(2);
                String ret_city = res.getString(3);

                results.add(new SearchResult(id, name, ret_city));
            }
        }
        finally {
            conn.close();
        }

        return results;
    }

    public static ArrayList<SearchResult> getByQuery(String query, String region) throws SQLException {
        Connection conn = DB.getConnection();

        ArrayList<SearchResult> results = new ArrayList<SearchResult>();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT id,name,city FROM do_search_school(?) WHERE region=?;");
            st.setString(1, query);
            st.setString(2, region);

            ResultSet res = st.executeQuery();

            while (res.next()) {
                Long id = res.getLong(1);
                String name = res.getString(2);
                String ret_city = res.getString(3);

                results.add(new SearchResult(id, name, ret_city));
            }
        }
        finally {
            conn.close();
        }

        return results;
    }

    public static ArrayList<SearchResult> getByQuery(String query) throws SQLException {
        Connection conn = DB.getConnection();

        ArrayList<SearchResult> results = new ArrayList<SearchResult>();

        try {
            PreparedStatement st = conn.prepareStatement("SELECT id,name,city FROM do_search_school(?);");
            st.setString(1, query);

            ResultSet res = st.executeQuery();

            while (res.next()) {
                Long id = res.getLong(1);
                String name = res.getString(2);
                String ret_city = res.getString(3);

                results.add(new SearchResult(id, name, ret_city));
            }
        }
        finally {
            conn.close();
        }

        return results;
    }

}
