Charts.colors = [ '#C3252E', '#7C51A1' ];

Charts.getRoute = function(category) {
    return jsRoutes.controllers.Attendance.alert(this.project);
};

Charts.load = function(project, region, state) {
    this.project = project;
    this.region = region;
    this.state = state;

    var level;
    if (region === '') {
        level = "brazil";

        // if level is "brazil", rotate xAxis labels
        this.barChartOptions.xAxis.labels.rotation = -45;
        this.barChartOptions.xAxis.labels.align = 'right';
        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.alertRegion(project, category);
        };
    }
    else if (state === '') {
        level = "region";

        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.alertState(project, region, category);
        };
    }
    else {
        level = "state";

        // if in "state" level, rotate the barChart (swap from columns to bars)
        this.barChartOptions.chart.defaultSeriesType = "bar";
        this.barChartOptions.xAxis.alternateGridColor = '#f3fff5';
        this.barChartOptions.tooltip.positioner = function(labelWidth, labelHeight, point) {
            return {x: 350-labelWidth, y: 30+point.plotY};
        };

        this.getRoute = function(category) {
            return jsRoutes.controllers.Reports.alertCity(project, region, state, category);
        };

        this.click = function(category) {
            window.open(this.getRoute(category).url, '_blank');
        }
    }

    this.barChartOptions.colors = this.colors;
    this.pieChartOptions.colors = this.colors;
    this.histChartOptions.colors = this.colors;

    this.barChart = new Highcharts.Chart(this.barChartOptions);
    this.pieChart = new Highcharts.Chart(this.pieChartOptions);
    this.histChart = new Highcharts.Chart(this.histChartOptions);

    this.barChart.showLoading("Carregando...");
    this.pieChart.showLoading("Carregando...");
    this.histChart.showLoading("Carregando...");

    /* BAR CHART */
    jsRoutes.controllers.Data.alert().ajax({
        contentType: "application/json",
        data: '{"type": "sub", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if (data.hd.length == 0) {
                Charts.barChart.hideLoading();
                Charts.noData(Charts.barChart);
                return;
            }

            Charts.barChart.xAxis[0].setCategories(data.categories);

            Charts.barChart.addSeries({
                name: 'Disco',
                data: data.hd
            }, false);

            Charts.barChart.addSeries({
                name: 'Memória',
                data: data.mem
            }, false);

            if (level === "state") {
                Charts.barChart.setSize(357,30*data.categories.length,false);
            }

            Charts.barChart.redraw();

            Charts.barChart.hideLoading();

            $('.bar-chart-help').fadeIn('slow');
        },
        error: this.error
    });

    /* PIE CHART */
    jsRoutes.controllers.Data.alert().ajax({
        contentType: "application/json",
        data: '{"type": "current", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if ( ((data.hd[0] == 0) &&
                  (data.mem[0] == 0)) || (data.hd.length == 0) ) {
                Charts.pieChart.hideLoading();
                Charts.noData(Charts.pieChart);
                return;
            }

            Charts.pieChart.addSeries({
                name: 'Número de Máquinas',
                data: [
                    ['Disco', data.hd[0]],
                    ['Memória', data.mem[0]],
                ]
            });

            Charts.pieChart.hideLoading();
        },
        error: this.error
    });

    /* HIST CHART */
    jsRoutes.controllers.Data.alert().ajax({
        contentType: "application/json",
        data: '{"type": "historical", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if (data.hd.length == 0) {
                Charts.histChart.hideLoading();
                Charts.noData(Charts.histChart);
                return;
            }

            Charts.histChart.xAxis[0].setCategories(data.categories);

            Charts.histChart.addSeries({
                name: 'Alteração de Disco',
                data: data.hd
            }, false);

            Charts.histChart.addSeries({
                name: 'Alteração de Memória',
                data: data.mem
            }, false);

            Charts.histChart.redraw();

            Charts.histChart.hideLoading();
        },
        error: this.error
    });
};
