Charts.getRoute = function(category) {
    return jsRoutes.controllers.Attendance.availability(this.project);
};

Charts.load = function(project, region, state) {
    this.project = project;
    this.region = region;
    this.state = state;

    var level;
    if (region === '') {
        level = "brazil";

        // if level is "brazil", rotate xAxis labels
        this.barChartOptions.xAxis.labels.rotation = -45;
        this.barChartOptions.xAxis.labels.align = 'right';
        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.availabilityRegion(project, category);
        };
    }
    else if (state === '') {
        level = "region";

        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.availabilityState(project, region, category);
        };
    }
    else {
        level = "state";

        // if in "state" level, rotate the barChart (swap from columns to bars)
        this.barChartOptions.chart.defaultSeriesType = "bar";
        this.barChartOptions.xAxis.alternateGridColor = '#f3fff5';
        this.barChartOptions.tooltip.positioner = function(labelWidth, labelHeight, point) {
            return {x: 350-labelWidth, y: 30+point.plotY};
        };

        this.getRoute = function(category) {
            return jsRoutes.controllers.Reports.availabilityCity(project, region, state, category);
        };

        this.click = function(category) {
            window.open(this.getRoute(category).url, '_blank');
        }
    }

    this.barChartOptions.colors = this.colors;
    this.pieChartOptions.colors = this.colors;
    this.histChartOptions.colors = this.colors;

    this.barChart = new Highcharts.Chart(this.barChartOptions);
    this.pieChart = new Highcharts.Chart(this.pieChartOptions);
    this.histChart = new Highcharts.Chart(this.histChartOptions);

    this.barChart.showLoading("Carregando...");
    this.pieChart.showLoading("Carregando...");
    this.histChart.showLoading("Carregando...");

    /* BAR CHART */
    jsRoutes.controllers.Data.availability().ajax({
        contentType: "application/json",
        data: '{"type": "sub", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if (data.green.length == 0) {
                Charts.barChart.hideLoading();
                Charts.noData(Charts.barChart);
                return;
            }

            Charts.barChart.xAxis[0].setCategories(data.categories);

            Charts.barChart.addSeries({
                name: 'Menos de 10 dias',
                data: data.green
            }, false);

            Charts.barChart.addSeries({
                name: 'Entre 11 e 30 dias',
                data: data.yellow
            }, false);

            Charts.barChart.addSeries({
                name: 'Mais de 30 dias',
                data: data.red
            }, false);

            if (level === "state") {
                Charts.barChart.setSize(357,30*data.categories.length, false);
            }

            Charts.barChart.redraw();

            Charts.barChart.hideLoading();

            $('.bar-chart-help').fadeIn('slow');
        },
        error: this.error
    });

    /* PIE CHART */
    jsRoutes.controllers.Data.availability().ajax({
        contentType: "application/json",
        data: '{"type": "current", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if ( ((data.green[0] == 0) &&
                  (data.yellow[0] == 0) &&
                  (data.red[0] == 0)) || (data.green.length == 0) ) {
                Charts.pieChart.hideLoading();
                Charts.noData(Charts.pieChart);
                return;
            }

            Charts.pieChart.addSeries({
                name: 'Número de Máquinas',
                data: [
                    ['Menos de\\10 dias', data.green[0]],
                    ['Entre 11\\e 30 dias', data.yellow[0]],
                    ['Mais de\\30 dias', data.red[0]],
                ]
            });

            Charts.pieChart.hideLoading();
        },
        error: this.error
    });

    /* HIST CHART */
    jsRoutes.controllers.Data.availability().ajax({
        contentType: "application/json",
        data: '{"type": "historical", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if (data.green.length == 0) {
                Charts.histChart.hideLoading();
                Charts.noData(Charts.histChart);
                return;
            }

            Charts.histChart.xAxis[0].setCategories(data.categories);

            Charts.histChart.addSeries({
                name: 'Último contato há menos de 10 dias',
                data: data.green
            }, false);

            Charts.histChart.addSeries({
                name: 'Último contato entre 11 e 30 dias',
                data: data.yellow
            }, false);

            Charts.histChart.addSeries({
                name: 'Último contato há mais de 30 dias',
                data: data.red
            }, false);

            Charts.histChart.redraw();

            Charts.histChart.hideLoading();
        },
        error: this.error
    });
};
