var Charts = {

    barChartOptions: {
        chart: {
            renderTo: 'barchart',
            backgroundColor: null,
            height: '300',
            defaultSeriesType: 'column'
        },
        title: {
            text: ''
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        xAxis: {
            categories: [],
            labels: {
                style: {
                    fontSize: '11px'
                },
                formatter: function() {
                    return '<a onclick="Charts.click(\''+this.value+'\');" style="color: #08C; cursor: pointer">' + this.value + '</a>';
                },
            },
        },
        yAxis: {
            min: 0,
            title: {
                text: 'Número de Máquinas'
            },
            labels: {
                formatter: function() {
                    return formatNumber(this.value);
                }
            }
        },
        credits: {
            enabled: false
        },
        legend: {
            enabled: false
        },
        tooltip: {
            shared: true,
            formatter: function() {
                var s = '<b>'+ this.x +'</b>';

                for (var i = 0; i < this.points.length; i++) {
                    var point = this.points[i];
                    s += '<br/><span>' +
                        point.series.name + '</span>: ' + formatNumber(point.y) + ' máquinas';
                };

                return s;
            },
            positioner: function() {
                return {x: 2, y: 2};
            }
        },
        plotOptions: {
            series: {
                groupPadding: 0.15,
                pointPadding: 0,
                cursor: 'pointer',
                events: {
                    click: function(event) {
                        var cat = event.point.category;
                        Charts.click(event.point.category);
                    }
                }
            }
        },
        series: []
    },

    pieChartOptions: {
        chart: {
            renderTo: 'piechart',
            type: 'pie',
            backgroundColor: null,
            height: '300',
        },
        title: {
            text: ''
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            formatter: function() {
                return '<b>' + this.key.replace('\\', ' ') + '</b><br/>' + formatNumber(this.y) + ' máquinas'
            }
        },
        plotOptions: {
            pie: {
                dataLabels: {
                    enabled: true,
                    distance: 5,
                    connectorWidth: 0,
                    formatter: function() {
                        return '<b>'+ this.point.name.split('\\').join('</b><br/><b>') +
                               '</b><br/>' + Math.round(this.percentage) + '%';
                    }
                }
            }
        },
        series: []
    },

    histChartOptions: {
        chart: {
            renderTo: 'history',
            type: 'line',
            backgroundColor: null,
            height: '300',
        },
        title: {
            text: 'Histórico dos últimos 6 meses'
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        xAxis: {
            categories: []
        },
        yAxis: {
            min: 0,
            title: {
                text: 'Número de Máquinas'
            },
            labels: {
                formatter: function() {
                    return formatNumber(this.value);
                }
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            crosshairs: {
                width: 2,
                color: 'gray',
                dashStyle: 'shortdot'
            },
            formatter: function() {
                var s = '<b>'+ this.x +'</b>';

                for (var i = 0; i < this.points.length; i++) {
                    var point = this.points[i];
                    s += '<br/><span>' +
                        point.series.name + '</span>: ' + formatNumber(point.y) + ' máquinas';
                };

                return s;
            },
            positioner: function () {
            	return { x: 10, y: 10 };
            },
            shared: true
        },
        plotOptions: {
            series: {
                groupPadding: 0.05
            }
        },
        legend: {
            layout: 'vertical',
            itemMarginTop: 3,
            itemMarginBottom: 3
        },
        series: []
    },

    colors: [
        '#a9c33c',
        '#eeba28',
        '#c3252e',
    ],

    click: function(category) {
        window.location = this.getRoute(category).url;
    },

    getRoute: function(category) {
        return null;
    },

    error: function(err) {
        console.log(err);

        $('#error').fadeIn('slow');

        Charts.barChart.destroy();
        Charts.pieChart.destroy();
        Charts.histChart.destroy();
    },

    noDataCount: 0,
    noData: function(chart) {
        this.noDataCount++;

        if (typeof chart !== 'undefined') {
            chart.destroy();
        }

        if (this.noDataCount >= 3) {
            $('#no-data').fadeIn('slow');
        }
    }
};
