Charts.getRoute = function(category) {
    return jsRoutes.controllers.Attendance.inventory(this.project);
};

Charts.load = function(project, region, state) {
    this.project = project;
    this.region = region;
    this.state = state;

    var level;
    if (region === '') {
        level = "brazil";

        // if level is "brazil", rotate xAxis labels
        this.barChartOptions.xAxis.labels.rotation = -45;
        this.barChartOptions.xAxis.labels.align = 'right';
        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.inventoryRegion(project, category);
        };
    }
    else if (state === '') {
        level = "region";

        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.inventoryState(project, region, category);
        };
    }
    else {
        level = "state";

        // if in "state" level, rotate the barChart (swap from columns to bars)
        this.barChartOptions.chart.defaultSeriesType = "bar";
        this.barChartOptions.xAxis.alternateGridColor = '#f3fff5';
        this.barChartOptions.tooltip.positioner = function(labelWidth, labelHeight, point) {
            return {x: 350-labelWidth, y: 30+point.plotY};
        };

        this.getRoute = function(category) {
            return jsRoutes.controllers.Reports.inventoryCity(project, region, state, category);
        };

        this.click = function(category) {
            window.open(this.getRoute(category).url, '_blank');
        }
    }

    this.barChartOptions.colors = this.colors;
    this.histChartOptions.colors = this.colors;

    this.barChart = new Highcharts.Chart(this.barChartOptions);
    this.histChart = new Highcharts.Chart(this.histChartOptions);

    this.barChart.showLoading("Carregando...");
    this.histChart.showLoading("Carregando...");

    // pie chart doesnt exist, so we call noData to increase the noData counter
    Charts.noData();

    /* BAR CHART */
    jsRoutes.controllers.Data.inventory().ajax({
        contentType: "application/json",
        data: '{"type": "sub", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if (data.total.length == 0) {
                Charts.barChart.hideLoading();
                Charts.noData(Charts.barChart);
                return;
            }

            Charts.barChart.xAxis[0].setCategories(data.categories);

            Charts.barChart.addSeries({
                name: 'Total de Máquinas',
                data: data.total
            }, false);

            if (level === "state") {
                Charts.barChart.setSize(357,30*data.categories.length, false);
            }

            Charts.barChart.redraw();

            Charts.barChart.hideLoading();

            $('.bar-chart-help').fadeIn('slow');
        },
        error: this.error
    });

    /* HIST CHART */
    jsRoutes.controllers.Data.inventory().ajax({
        contentType: "application/json",
        data: '{"type": "historical", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'"}',
        success: function(data) {
            if (data.total.length == 0) {
                Charts.histChart.hideLoading();
                Charts.noData(Charts.histChart);
                return;
            }

            Charts.histChart.xAxis[0].setCategories(data.categories);

            Charts.histChart.addSeries({
                name: 'Total de Máquinas',
                data: data.total
            });

            Charts.histChart.hideLoading();
        },
        error: this.error
    });
};
