Charts.colors = [ '#2f7ed8' ];

Charts.getRoute = function(category) {
    return jsRoutes.controllers.Attendance.networkBrasil(this.project);
};

Charts.load = function(project, region, state, city) {
    this.project = project;
    this.region = region;
    this.state = state;
    this.city = city;

    var level;
    if (region === '') {
        level = "brazil";

        // if level is "brazil", rotate xAxis labels
        this.barChartOptions.xAxis.labels.rotation = -45;
        this.barChartOptions.xAxis.labels.align = 'right';
        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.networkRegion(project, category);
        };
    }
    else if (state === '') {
        level = "region";

        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.networkState(project, region, category);
        };
    }
    else if (city == '') {
        level = "state";

        // if in "state" level, rotate the barChart (swap from columns to bars)
        this.barChartOptions.chart.defaultSeriesType = "bar";
        this.barChartOptions.xAxis.alternateGridColor = '#f3fff5';
        this.barChartOptions.tooltip.positioner = function(labelWidth, labelHeight, point) {
            return {x: 350-labelWidth, y: 30+point.plotY};
        };

        this.getRoute = function(category) {
            return jsRoutes.controllers.Attendance.networkCity(project, region, state, category);
        };
    }
    else {
        level = "city";

        // if in "city" level, rotate the barChart (swap from columns to bars)
        this.barChartOptions.chart.defaultSeriesType = "bar";
        this.barChartOptions.xAxis.alternateGridColor = '#f3fff5';
        this.barChartOptions.tooltip.positioner = function(labelWidth, labelHeight, point) {
            return {x: 350-labelWidth, y: 30+point.plotY};
        };

        this.click = function(category) {
            var tempForm = document.createElement("form");
            tempForm.action = jsRoutes.controllers.Attendance.schoolByName().url;
            tempForm.method = "POST";
            tempForm.enctype = "multipart/form-data";
            tempForm.style.display = "none";

            var tempInput=document.createElement("input");
            tempInput.name = 'name';
            tempInput.value = category;

            tempForm.appendChild(tempInput);
            document.body.appendChild(tempForm);
        	tempForm.submit();
        };
    }

    this.barChartOptions.colors = this.colors;
    this.histChartOptions.colors = this.colors;

    this.barChart = new Highcharts.Chart(this.barChartOptions);
    this.histChart = new Highcharts.Chart(this.histChartOptions);

    this.barChart.showLoading("Carregando...");
    this.histChart.showLoading("Carregando...");


    // pie chart doesnt exist, so we call noData to increase the noData counter
    Charts.noData();

    /* BAR CHART */
    jsRoutes.controllers.Data.inventory().ajax({
        contentType: "application/json",
        data: '{"type": "sub", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'", "city": "'+city+'"}',
        success: function(data) {
            if (data.total.length == 0) {
                Charts.barChart.hideLoading();
                Charts.noData(Charts.barChart);
                return;
            }

            Charts.barChart.xAxis[0].setCategories(data.categories);

            Charts.barChart.addSeries({
                name: 'Total de Máquinas',
                data: data.total
            }, false);

            if (level === "state") {
                Charts.barChart.setSize(482,30*data.categories.length, false);
            }
            else if (level === "city") {
                Charts.barChart.setSize(482,50*data.categories.length, false);
            }

            Charts.barChart.redraw();

            Charts.barChart.hideLoading();

            $('.bar-chart-help').fadeIn('slow');
        },
        error: this.error
    });

    /* HIST CHART */
    jsRoutes.controllers.Data.inventory().ajax({
        contentType: "application/json",
        data: '{"type": "historical", "level": "'+level+'", "project": "'+
            project + '", "region": "'+region+'", "state": "'+state+'", "city": "'+city+'"}',
        success: function(data) {
            if (data.total.length == 0) {
                Charts.histChart.hideLoading();
                Charts.noData(Charts.histChart);
                return;
            }

            Charts.histChart.xAxis[0].setCategories(data.categories);

            Charts.histChart.addSeries({
                name: 'Total de Máquinas',
                data: data.total
            });

            Charts.histChart.hideLoading();
        },
        error: this.error
    });
};
