Highcharts.setOptions({
    lang: {
        loading: 'Carregando...',
        months: ['Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro', 'Novembro', 'Dezembro'],
        weekdays: ['Domingo', 'Segunda', 'Terça', 'Quarta', 'Quinta', 'Sexta', 'Sábado'],
        shortMonths: ['Jan', 'Feb', 'Mar', 'Abr', 'Maio', 'Jun', 'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez'],
        exportButtonTitle: "Exportar",
        printButtonTitle: "Imprimir",
        rangeSelectorFrom: "De",
        rangeSelectorTo: "Até",
        rangeSelectorZoom: "Período",
        downloadPNG: 'Download imagem PNG',
        downloadJPEG: 'Download imagem JPEG',
        downloadPDF: 'Download documento PDF',
        downloadSVG: 'Download imagem SVG',
        thousandsSep: ".",
        decimalPoint: ','
        // resetZoom: "Reset",
        // resetZoomTitle: "Reset,
        }
    }
);

var Charts = {

    pieChartOptions: {
        chart: {
            renderTo: 'piechart',
            type: 'pie',
            backgroundColor: null,
            height: '400',
            events: {
                load: function () {
                    var ren = this.renderer,
                        colors = Highcharts.getOptions().colors,
                        rightArrow = ['M', 0, 0, 'L', 100, 0, 'L', 95, 5, 'M', 100, 0, 'L', 95, -5],
                        leftArrow = ['M', 100, 0, 'L', 0, 0, 'L', 5, 5, 'M', 0, 0, 'L', 5, -5];

                    ren.label('Linux Educacional', 570, 70).css({
                        fontWeight: 'bold',
                        color: '#437600'
                    }).add();

                    ren.label('Windows', 570, 190).css({
                        fontWeight: 'bold',
                        color: '#18537D'
                    }).add();

                    ren.label('Outros', 570, 310).css({
                        fontWeight: 'bold',
                        color: '#8F1111'
                    }).add();
                }
            }
        },
        title: {
            text: ''
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            formatter: function() {
                return '<b>' + this.key.replace('\\', ' ') + '</b><br/>' + formatNumber(this.y) + ' máquinas'
            }
        },
        plotOptions: {
            pie: {
                dataLabels: {
                    enabled: true,
                    formatter: function() {
                        return this.percentage > 1 ?
                            '<b>' + this.point.name.split('\\').join('</b><br/><b>') +
                            '</b><br/>' + this.percentage.toFixed(1) + '%' : null;
                    }
                }
            }
        },
        series: []
    },

    histChartOptions: {
        chart: {
            renderTo: 'history',
            type: 'line',
            backgroundColor: null,
            height: '400',
        },
        title: {
            text: 'Histórico dos últimos 6 meses'
        },
        loading: {
            labelStyle: {
                top: '45%',
            }
        },
        xAxis: {
            type: 'datetime',
            tickInterval: 28*24*3600*1000, // 28 days
            dateTimeLabelFormats: {
                day: '%B',
                week: '%B',
                month: '%B',
                year: '%B'
            }
        },
        yAxis: {
            min: 0,
            title: {
                text: 'Número de Máquinas'
            },
            labels: {
                formatter: function() {
                    return formatNumber(this.value);
                }
            }
        },
        credits: {
            enabled: false
        },
        tooltip: {
            crosshairs: {
                width: 2,
                color: 'gray',
                dashStyle: 'shortdot'
            },
            formatter: function() {
                var s = '<b>'+ Highcharts.getOptions().lang.months[new Date(this.x).getMonth()] +'</b>';

                for (var i = 0; i < this.points.length; i++) {
                    var point = this.points[i];
                    s += '<br/><span style="font-weight: bold; color: ' + point.series.color + '">' +
                        point.series.name + '</span>: ' + formatNumber(point.y) + ' máquinas';
                };

                return s;
            },
            shared: true
        },
        plotOptions: {
            series: {
                groupPadding: 0.05
            }
        },
        series: []
    },

    load: function(project) {
        this.project = project;

        this.pieChart = new Highcharts.Chart(this.pieChartOptions);
        this.histChart = new Highcharts.Chart(this.histChartOptions);

        this.pieChart.showLoading("Carregando...");
        this.histChart.showLoading("Carregando...");

        var colors = Highcharts.getOptions().colors;

        var categories = {
            le: {
                name: 'Linux Educacional',
                color: '#68950A'
            },
            windows: {
                name: 'Windows',
                color: '#18537D'
            },
            others: {
                name: 'Outros',
                color: '#8F1111',
            }

        };

        var distros = {
            'Linux Educacional 5.0':    {color: '#437600', name: 'LE5', category: categories.le},
            'Linux Educacional 4.0':    {color: '#68950A', name: 'LE4', category: categories.le},
            'Linux Educacional 3.0':    {color: '#8DB414', name: 'LE3', category: categories.le},
            'Linux Educacional 2.0':    {color: '#B2D31D', name: 'LE2', category: categories.le},
            'Linux Educacional 1.0':    {color: '#D7F227', name: 'LE1', category: categories.le},
            'Windows 7':                {color: '#18537D', name: 'Win7', category: categories.windows},
            'Windows MultiPoint Server':{color: '#73A0B4', name: 'MultiPoint', category: categories.windows},
            'Ubuntu':                   {color: '#8F1111', name: 'Ubuntu', category: categories.others},
            'Debian':                   {color: '#C25147', name: 'Debian', category: categories.others},
            'Outros':                   {color: '#F5917D', name: 'Outros', category: categories.others},
        };
        var DEFAULT_DISTRO = {color: '#FFFEDE', category: categories.others};

        /* PIE CHART */
        jsRoutes.controllers.Data.os().ajax({
            contentType: "application/json",
            data: '{"type": "current", "project": "'+project+'"}',
            success: function(data) {
                var total = 0;

                categories.le.y = 0;
                categories.windows.y = 0;
                categories.others.y = 0;

                for (d in distros) {
                    distros[d].y = 0;
                }

                var distrosArray = [];
                for (var i = 0; i < data.length; i++) {
                    var val = parseInt(data[i].data[0][1]);
                    var distro = distros[data[i].name];

                    /*if (key === "Linux Educacional 4.0") {
                        val = 1;
                    }*/

                    if (typeof distro === 'undefined') {
                        distro = DEFAULT_DISTRO;
                    }

                    distro.category.y += val;
                    distro.y += val;
                    total += val;
                };

                var les = [],
                    windows = [],
                    others = [];

                for (d in distros) {
                    if (distros[d].category === categories.le) {
                        les.push(distros[d]);
                    }
                    else if (distros[d].category === categories.windows) {
                        windows.push(distros[d]);
                    }
                    else {
                        others.push(distros[d]);
                    }
                }

                Charts.pieChart.addSeries({
                    name: 'Sistemas Operacionais',
                    data: [ categories.le, categories.windows, categories.others ],
                    size: '70%',
                    center: [200,200],
                    shadow: true,
                    dataLabels: {
                        formatter: function() {
                            return '<b>' + this.point.name.split('\\').join('</b><br/><b>') +
                                '</b><br/>' + this.percentage.toFixed(1) + '%';
                        }
                    }
                });

                Charts.pieChart.addSeries({
                    name: 'Linux Educacional',
                    data: les,
                    size: '30%',
                    center: [480,70],
                    shadow: true,
                    dataLabels: {
                        borderRadius: 2,
                        backgroundColor: 'rgba(255, 255, 255, 0.7)',
                        borderWidth: 0,
                        distance: -30,
                    }
                });

                Charts.pieChart.addSeries({
                    name: 'Windows',
                    data: windows,
                    size: '30%',
                    center: [480,190],
                    shadow: true,
                    dataLabels: {
                        borderRadius: 2,
                        backgroundColor: 'rgba(255, 255, 255, 0.7)',
                        borderWidth: 0,
                        distance: -30
                    }
                });

                Charts.pieChart.addSeries({
                    name: 'Outros',
                    data: others,
                    size: '30%',
                    center: [480,310],
                    shadow: true,
                    dataLabels: {
                        borderRadius: 2,
                        backgroundColor: 'rgba(255, 255, 255, 0.7)',
                        borderWidth: 0,
                        distance: -30
                    }
                });

                /*Charts.pieChart.addSeries({
                    name: 'Versões',
                    data: les.concat(windows, others),
                    size: '80%',
                    innerSize: '60%',
                    dataLabels: {
                        formatter: function() {
                            // display only if larger than 1 percent
                            return this.percentage > 1 ? '<b>'+ this.point.name +':</b> '+ this.percentage.toFixed(1) + '%' : null;
                        },
                        distance: 10
                    }
                });*/

                Charts.pieChart.hideLoading();
            },
            error: function(err) {
                console.log(err);
            }
        });

        /* HIST CHART */
        jsRoutes.controllers.Data.os().ajax({
            contentType: "application/json",
            data: '{"type": "historical", "project": "'+project+'"}',
            success: function(data) {
                for (var i = 0; i < data.length; i++) {
                    var serie = data[i];
                    var distro = distros[serie.name];

                    if (typeof distro === 'undefined') {
                        distro = DEFAULT_DISTRO;
                    }

                    for (var j=0; j < serie.data.length; j++) {
                        serie.data[j][0] = parseInt(serie.data[j][0]);
                        serie.data[j][1] = parseInt(serie.data[j][1]);
                    };

                    Charts.histChart.addSeries({
                        name: serie.name,
                        data: serie.data,
                        color: distro.color
                    }, false);
                };

                Charts.histChart.redraw();

                Charts.histChart.hideLoading();

                $('.bar-chart-help').fadeIn('slow');
            },
            error: function(err) {
                console.log(err);
            }
        });
    }
};
